/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 03088
 |           ALCOHOL AND DRUG SERVICES STUDY (ADSS), 1996-1999:
 |                            [UNITED STATES]
 |            (DATASET 0002: PHASE II ADMINISTRATOR INTERVIEW)
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\03088-0002-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE q1ffffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  99995='(99995) 99995 OR MORE CLIENTS' ;
  VALUE q2a       -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q2b       -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q2c       -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q2d       -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q3a       -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 99995='(99995) 99995 OR MORE CLIENTS' ;
  VALUE q3b       -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 99995='(99995) 99995 OR MORE CLIENTS' ;
  VALUE q3c       -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 99995='(99995) 99995 OR MORE CLIENTS' ;
  VALUE q3d       -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 99995='(99995) 99995 OR MORE CLIENTS' ;
  VALUE q3tot     -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  99995='(99995) 99995 OR MORE CLIENTS' ;
  VALUE q4a       -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) NOT APPLICABLE (DO NOT HAVE)' 1='(1) YES (COPY OBTAINED)' ;
  VALUE q4b       -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) NOT APPLICABLE (DO NOT HAVE)' 1='(1) YES (COPY OBTAINED)' ;
  VALUE q4c       -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) NOT APPLICABLE (DO NOT HAVE)' 1='(1) YES (COPY OBTAINED)' ;
  VALUE q4d       -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) NOT APPLICABLE (DO NOT HAVE)' 1='(1) YES (COPY OBTAINED)' ;
  VALUE q4e       -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) NOT APPLICABLE (DO NOT HAVE)' 1='(1) YES (COPY OBTAINED)' ;
  VALUE q4f       -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) NOT APPLICABLE (DO NOT HAVE)' 1='(1) YES (COPY OBTAINED)' ;
  VALUE q4g       -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) NOT APPLICABLE (DO NOT HAVE)' 1='(1) YES (COPY OBTAINED)' ;
  VALUE q4h       -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) NOT APPLICABLE (DO NOT HAVE)' 1='(1) YES (COPY OBTAINED)' ;
  VALUE q4i       -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) NOT APPLICABLE (DO NOT HAVE)' 1='(1) YES (COPY OBTAINED)' ;
  VALUE q4j       -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) NOT APPLICABLE (DO NOT HAVE)' 1='(1) YES (COPY OBTAINED)' ;
  VALUE q4k       -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) NOT APPLICABLE (DO NOT HAVE)' 1='(1) YES (COPY OBTAINED)' ;
  VALUE boxa      -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) BOX CHECKED' 2='(2) BOX NOT CHECKED' ;
  VALUE boxb      -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) BOX CHECKED' 2='(2) BOX NOT CHECKED' ;
  VALUE boxc      -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) BOX CHECKED' 2='(2) BOX NOT CHECKED' ;
  VALUE boxd      -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) BOX CHECKED' 2='(2) BOX NOT CHECKED' ;
  VALUE q5a       -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 9995='(9995) 9995 OR MORE BEDS' ;
  VALUE q5b       -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 9995='(9995) 9995 OR MORE BEDS' ;
  VALUE q5c       -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 9995='(9995) 9995 OR MORE BEDS' ;
  VALUE q6a       -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 9995='(9995) 9995 OR MORE ADMISSIONS' ;
  VALUE q6b       -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 9995='(9995) 9995 OR MORE ADMISSIONS' ;
  VALUE q6c       -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 9995='(9995) 9995 OR MORE ADMISSIONS' ;
  VALUE q7a       -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q7au      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) DAYS' 2='(2) WEEKS' 3='(3) MONTHS' ;
  VALUE q7b       -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q7bu      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) DAYS' 2='(2) WEEKS' 3='(3) MONTHS' ;
  VALUE q7c       -9='(-9) INAPPLICABLE, Q7A AND Q7B ANSWERED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE q7cu      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) DAYS' 2='(2) WEEKS' 3='(3) MONTHS' ;
  VALUE q8fmm     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q8fdd     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q8fyy     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q8tmm     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q8tdd     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q8tyy     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q9a       -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q9b       -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q9c       -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q9d       -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q10a      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q11a      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q10b      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q11b      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q10c      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q11c      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q10d      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q11d      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q10e      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q10es     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 96='(96) SPECIFIC SESSION CONTENT REPORTED' ;
  VALUE q11e      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW'
                  -1='(-1) DIFFERENT GROUPS, NUMBERS IN EACH GROUP' ;
  VALUE q12a      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 9995='(9995) 9995 OR MORE BEDS'
                  9996='(9996) NO SET NUMBER OF BEDS' ;
  VALUE q12b      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 9995='(9995) 9995 OR MORE BEDS'
                  9996='(9996) NO SET NUMBER OF BEDS' ;
  VALUE q12c      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 9995='(9995) 9995 OR MORE BEDS'
                  9996='(9996) NO SET NUMBER OF BEDS' ;
  VALUE q13a      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 9995='(9995) 9995 OR MORE ADMISSIONS' ;
  VALUE q13b      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 9995='(9995) 9995 OR MORE ADMISSIONS' ;
  VALUE q13c      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 9995='(9995) 9995 OR MORE ADMISSIONS' ;
  VALUE q14fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q15a      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q15au     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) DAYS' 2='(2) WEEKS' 3='(3) MONTHS' 4='(4) YEARS' ;
  VALUE q15b      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q15bu     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) DAYS' 2='(2) WEEKS' 3='(3) MONTHS' 4='(4) YEARS' ;
  VALUE q15c      -9='(-9) INAPPLICABLE, Q15A AND Q15B ANSWERED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE q15cu     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) DAYS' 2='(2) WEEKS' 3='(3) MONTHS' 4='(4) YEARS' ;
  VALUE q16fmm    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q16fdd    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q16fyy    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q16tmm    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q16tdd    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q16tyy    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q17a      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q17b      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q17c      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q17d      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q18a      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q19a      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q18b      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q19b      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q18c      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q19c      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q18d      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q19d      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q18e      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q18es     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 96='(96) SPECIFIC SESSION CONTENT REPORTED' ;
  VALUE q19e      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q20fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 9995='(9995) 9995 OR MORE ADMISSIONS' ;
  VALUE q21fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW'
                  -1='(-1) MAJORITY OF CLIENTS STAY RANGES FROM 3 M' ;
  VALUE q21u      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) DAYS' 2='(2) WEEKS' 3='(3) MONTHS' 4='(4) YEARS' ;
  VALUE q22fmm    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q22fdd    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q22fyy    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q22tmm    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q22tdd    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q22tyy    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q23a      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q23b      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q24a      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q25a      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q24b      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q25b      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q24c      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q25c      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q24d      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q25d      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q24e      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q24es     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 96='(96) SPECIFIC SESSION CONTENT REPORTED' ;
  VALUE q25e      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q26fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q27fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 9995='(9995) 9995 OR MORE ADMISSIONS' ;
  VALUE q28fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' -1='(-1) MORE THAN 1 LENGTH OF STAY GIVEN' ;
  VALUE q28u      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) DAYS' 2='(2) WEEKS' 3='(3) MONTHS' 4='(4) YEARS'
                  5='(5) SESSIONS' ;
  VALUE q29fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q30fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q31fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) NO PATIENTS STAYED FOR DETOX' ;
  VALUE q31u      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) DAYS' 2='(2) WEEKS' 3='(3) MONTHS' ;
  VALUE q32fmm    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q32fdd    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q32fyy    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q32tmm    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q32tdd    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q32tyy    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q33a      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW'
                  -1='(-1) VARIES BY CHARACTERISTICS OF CLIENT OR T' ;
  VALUE q33b      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW'
                  -1='(-1) VARIES BY CHARACTERISTICS OF CLIENT OR T' ;
  VALUE q34a      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q35a      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q34b      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q35b      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q34c      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q35c      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q34d      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q35d      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q34e      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q34es     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 96='(96) SPECIFIC SESSION CONTENT REPORTED' ;
  VALUE q35e      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q36fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q37fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q38fffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE q39fffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE q40a      -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q40b      -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q40c      -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q41fffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q42a      -9='(-9) INAPPLICABLE, CODED NO IN Q41' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q42b      -9='(-9) INAPPLICABLE, CODED NO IN Q41' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q42c      -9='(-9) INAPPLICABLE, CODED NO IN Q41' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q42d      -9='(-9) INAPPLICABLE, CODED NO IN Q41' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q42e      -9='(-9) INAPPLICABLE, CODED NO IN Q41' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q42f      -9='(-9) INAPPLICABLE, CODED NO IN Q41' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q42g      -9='(-9) INAPPLICABLE, CODED NO IN Q41' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q42h      -9='(-9) INAPPLICABLE, CODED NO IN Q41' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q42i      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q42j      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q43fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q44fffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q45fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) THIS FACILITY ONLY'
                  2='(2) INCLUDES OTHER ENTITIES' ;
  VALUE q45b      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q45c      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q46fffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q46oth1f  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) FURNITURE/FURNISHINGS' 2='(2) EQUIPMENT'
                  3='(3) FOOD' 4='(4) BEDDING' 5='(5) CLOTHING' 6='(6) SPACE/UTILITIES'
                  7='(7) TAX RELIEF/TAX -EXEMPT STATUS'
                  8='(8) DISCOUNTED FACILITY RENTAL'
                  9='(9) VOLUNTEER SERVICES (NON-PROFESSIONAL, UN'
                  10='(10) PROFESSIONAL SERVICES'
                  11='(11) SUPPLIES (OFFICE, CLINICAL, EDUCATIONAL,'
                  12='(12) PATIENT GIFTS & ENTERTAINMENT' 96='(96) MISCELLANEOUS' ;
  VALUE q46oth2f  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) FURNITURE/FURNISHINGS' 2='(2) EQUIPMENT'
                  3='(3) FOOD' 4='(4) BEDDING' 5='(5) CLOTHING' 6='(6) SPACE/UTILITIES'
                  7='(7) TAX RELIEF/TAX -EXEMPT STATUS'
                  8='(8) DISCOUNTED FACILITY RENTAL'
                  9='(9) VOLUNTEER SERVICES (NON-PROFESSIONAL, UN'
                  10='(10) PROFESSIONAL SERVICES'
                  11='(11) SUPPLIES (OFFICE, CLINICAL, EDUCATIONAL,'
                  12='(12) PATIENT GIFTS & ENTERTAINMENT' 96='(96) MISCELLANEOUS' ;
  VALUE q46oth3f  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) FURNITURE/FURNISHINGS' 2='(2) EQUIPMENT'
                  3='(3) FOOD' 4='(4) BEDDING' 5='(5) CLOTHING' 6='(6) SPACE/UTILITIES'
                  7='(7) TAX RELIEF/TAX -EXEMPT STATUS'
                  8='(8) DISCOUNTED FACILITY RENTAL'
                  9='(9) VOLUNTEER SERVICES (NON-PROFESSIONAL, UN'
                  10='(10) PROFESSIONAL SERVICES'
                  11='(11) SUPPLIES (OFFICE, CLINICAL, EDUCATIONAL,'
                  12='(12) PATIENT GIFTS & ENTERTAINMENT' 96='(96) MISCELLANEOUS' ;
  VALUE q47box    -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) BOX IS CHECKED' 2='(2) BOX IS NOT CHECKED' ;
  VALUE r9a1ffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE r9b1ffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE r9c1ffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE r9d1ffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE r9e1ffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE r9f1ffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE r9g1ffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE r9h1ffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE r9i1ffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE r9a2ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE r9b2ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE r9c2ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE r9d2ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE r9e2ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE r9f2ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE r9g2ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE r9h2ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE r9i2ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE r9a3ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE r9b3ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE r9c3ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE r9d3ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE r9e3ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE r9f3ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE r9g3ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE r9h3ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE r9i3ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q47aw     -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE q47bw     -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE q47cw     -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE q47dw     -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE q47ew     -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE q47fw     -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE q47gw     -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE q47hw     -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE q47iw     -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE boxe      1='(1) ONLY ONE TYPE OF CARE OFFERED'
                  2='(2) MORE THAN ONE TYPE OF CARE OFFERED' ;
  VALUE q48a      -9='(-9) INAPPLICABLE, BOX E CODED 1' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE q48b      -9='(-9) INAPPLICABLE, BOX E CODED 1' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE q48c      -9='(-9) INAPPLICABLE, BOX E CODED 1' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE q48d      -9='(-9) INAPPLICABLE, BOX E CODED 1' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE q48e      -9='(-9) INAPPLICABLE, BOX E CODED 1' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE q49a      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' -1='(-1) MORE THAN ONE SALARY GIVEN' ;
  VALUE q49au     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) PER HOUR' 4='(4) PER YEAR' ;
  VALUE q50a      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q49b      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' -1='(-1) MORE THAN ONE SALARY GIVEN' ;
  VALUE q49bu     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) PER HOUR' 4='(4) PER YEAR' ;
  VALUE q50b      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q49c      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' -1='(-1) MORE THAN ONE SALARY GIVEN' ;
  VALUE q49cu     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) PER HOUR' 4='(4) PER YEAR' ;
  VALUE q50c      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q49d      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' -1='(-1) MORE THAN ONE SALARY GIVEN' ;
  VALUE q49du     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) PER HOUR' 4='(4) PER YEAR' ;
  VALUE q50d      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q49e      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' -1='(-1) MORE THAN ONE SALARY GIVEN' ;
  VALUE q49eu     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) PER HOUR' 4='(4) PER YEAR' ;
  VALUE q50e      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q49f      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' -1='(-1) MORE THAN ONE SALARY GIVEN' ;
  VALUE q49fu     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) PER HOUR' 4='(4) PER YEAR' ;
  VALUE q50f      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q49g      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' -1='(-1) MORE THAN ONE SALARY GIVEN' ;
  VALUE q49gu     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) PER HOUR' 4='(4) PER YEAR' ;
  VALUE q50g      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q49h      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' -1='(-1) MORE THAN ONE SALARY GIVEN' ;
  VALUE q49hu     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) PER HOUR' 4='(4) PER YEAR' ;
  VALUE q50h      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q51a      -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q51apc    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q51b      -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q51bpc    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q51c      -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q51cpc    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q51d      -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q51dpc    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q51e      -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q51epc    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q51f      -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q51fpc    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q51g      -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q51gpc    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q51h      -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q51hpc    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q51i      -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q51ipc    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q51j      -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q51jpc    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q51k      -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q51kpc    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q51l      -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q51lpc    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q51m      -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q51mpc    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q51n      -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q51npc    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q51o      -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q51opc    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q51p      -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q51ppc    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q51q      -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q51qpc    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q51r      -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE q51rpc    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q52fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q53fmm    -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE q53fdd    -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE q53fyy    -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE q53tmm    -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE q53tdd    -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE q53tyy    -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE q54box    -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) BOX IS CHECKED' 2='(2) BOX IS NOT CHECKED' ;
  VALUE q54pc     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q55fffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE q56box    -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) BOX IS CHECKED' 2='(2) BOX IS NOT CHECKED' ;
  VALUE q56pc     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE tmeh      -7='(-7) NOT ASCERTAINED' 95='(95) MULTIPLE SESSIONS TO COMPLETE' ;
  VALUE tmem      -7='(-7) NOT ASCERTAINED' 95='(95) MULTIPLE SESSIONS TO COMPLETE' ;
  VALUE tmeap     -7='(-7) NOT ASCERTAINED' 1='(1) AM' 2='(2) PM' 5='(5) MULTIPLE SESSIONS' ;
  VALUE q57fmm    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q57fdd    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q57fyy    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q57tmm    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q57tdd    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q57tyy    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q57a01ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q57b01n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q57b01p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q57a02ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q57b02n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q57b02p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q57a03ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q57b03n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q57b03p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q57a04ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q57b04n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q57b04p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q57a05ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q57b05n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q57b05p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q57a06ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q57b06n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q57b06p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q57a07ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q57b07n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q57b07p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q57a08ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q57b08n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q57b08p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q57a09ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q57a09s   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) SPECIFIC NAMED SOURCE'
                  2='(2) GENERIC SOURCE' 3='(3) CHARITY/CONTRIBUTIONS/FUNDRAISING'
                  4='(4) GRANTS' 5='(5) INSURANCE - NOT FURTHER CLASSIFIED'
                  96='(96) MISCELLANEOUS' ;
  VALUE q57b09n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q57b09p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q57a10ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q57b10n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q57b10p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q57btn    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q58fmm    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q58fdd    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q58fyy    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q58tmm    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q58tdd    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q58tyy    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q58a01ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q58b01n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q58b01p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q58a02ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q58b02n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q58b02p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q58a03ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q58b03n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q58b03p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q58a04ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q58b04n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q58b04p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q58a05ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q58b05n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q58b05p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q58a06ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q58b06n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q58b06p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q58a07ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q58b07n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q58b07p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q58a08ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q58b08n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q58b08p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q58a09ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q58a09s   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) SPECIFIC NAMED SOURCE'
                  2='(2) GENERIC SOURCE' 3='(3) CHARITY/CONTRIBUTIONS/FUNDRAISING'
                  4='(4) GRANTS' 5='(5) INSURANCE - NOT FURTHER CLASSIFIED'
                  96='(96) MISCELLANEOUS' ;
  VALUE q58b09n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q58b09p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q58a10ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q58b10n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q58b10p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q58btn    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q59fmm    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q59fdd    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q59fyy    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q59tmm    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q59tdd    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q59tyy    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q59a01ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q59b01n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q59b01p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q59a02ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q59b02n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q59b02p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q59a03ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q59b03n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q59b03p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q59a04ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q59b04n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q59b04p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q59a05ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q59b05n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q59b05p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q59a06ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q59b06n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q59b06p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q59a07ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q59b07n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q59b07p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q59a08ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q59b08n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q59b08p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q59a09ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q59a09s   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) SPECIFIC NAMED SOURCE'
                  2='(2) GENERIC SOURCE' 3='(3) CHARITY/CONTRIBUTIONS/FUNDRAISING'
                  4='(4) GRANTS' 5='(5) INSURANCE - NOT FURTHER CLASSIFIED'
                  96='(96) MISCELLANEOUS' ;
  VALUE q59b09n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q59b09p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q59a10ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q59b10n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q59b10p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q59btn    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q60fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q61fmm    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q61fdd    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q61fyy    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q61tmm    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q61tdd    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q61tyy    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q61a01ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q61b01n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q61b01p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q61a02ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q61b02n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q61b02p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q61a03ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q61b03n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q61b03p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q61a04ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q61b04n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q61b04p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q61a05ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q61b05n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q61b05p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q61a06ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q61b06n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q61b06p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q61a07ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q61b07n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q61b07p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q61a08ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q61b08n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q61b08p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q61a09ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q61a09s   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) SPECIFIC NAMED SOURCE'
                  2='(2) GENERIC SOURCE' 3='(3) CHARITY/CONTRIBUTIONS/FUNDRAISING'
                  4='(4) GRANTS' 5='(5) INSURANCE - NOT FURTHER CLASSIFIED'
                  96='(96) MISCELLANEOUS' ;
  VALUE q61b09n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q61b09p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q61a10ff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE q61b10n   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q61b10p   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE q61btn    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE bignt     -9='(-9) MISSING' ;
  VALUE smallnt   -9='(-9) MISSING' ;
  VALUE psutypef  1='(1) METRO CERTAINTY' 2='(2) METRO NONCERTAINTY'
                  3='(3) NONMETRO NONCERTAINTY' ;
  VALUE cenreg    1='(1) NORTHEAST' 2='(2) MIDWEST' 3='(3) SOUTH' 4='(4) WEST' ;
  VALUE ctclient  1='(1) NUMBER OF CLIENTS BETWEEN 0 AND 16'
                  2='(2) NUMBER OF CLIENTS BETWEEN 17 AND 40'
                  3='(3) NUMBER OF CLIENTS BETWEEN 41 AND 100'
                  4='(4) NUMBER OF CLIENTS BETWEEN 101 AND 225'
                  5='(5) NUMBER OF CLIENTS OVER 225' ;
  VALUE factype   2='(2) FACILITY OFFERS RESIDENTIAL TREATMENT ON'
                  3='(3) FACILITY OFFERS OUTPATIENT METHADONE TRE'
                  4='(4) FACILITY OFFERS OUTPATIENT NON-METHADONE'
                  5='(5) FACILITY OFFERS MORE THAN ONE TYPE OF TR' ;
  VALUE qfstrat   2='(2) STRATUM 2 RESIDENTIAL'
                  3='(3) STRATUM 3 PREDOMINANTLY OUTPATIENT METHA'
                  4='(4) STRATUM 4 OP NON-METH PREDOMINANTLY ALC'
                  5='(5) STRATUM 5 OP NON-METH - NOT IN STRATUM'
                  6='(6) STRATUM 6 COMBINATION' ;
  VALUE studyind  0='(0) INCENTIVE STUDY FACILITY' 1='(1) MAIN STUDY FACILITY' ;
  VALUE own       1='(1) PRIVATE FOR PROFIT' 2='(2) PRIVATE NONPROFIT' 3='(3) PUBLIC' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=2036;
INPUT
        CASEID 1-4              FACID 5-8               Q1 9-12
        Q2A 13-14               Q2B 15-16               Q2C 17-18
        Q2D 19-20               Q3A 21-22               Q3B 23-25
        Q3C 26-28               Q3D 29-32               Q3TOT 33-36
        Q4A 37-38               Q4B 39-40               Q4C 41-42
        Q4D 43-44               Q4E 45-46               Q4F 47-48
        Q4G 49-50               Q4H 51-52               Q4I 53-54
        Q4J 55-56               Q4K 57-58               BOXA 59-60
        BOXB 61-62              BOXC 63-64              BOXD 65-66
        Q5A 67-68               Q5B 69-70               Q5C 71-72
        Q6A 73-76               Q6B 77-80               Q6C 81-83
        Q7A 84-85               Q7AU 86-87              Q7B 88-91 .1
        Q7BU 92-93              Q7C 94-95               Q7CU 96-97
        Q8FMM 98-99             Q8FDD 100-101           Q8FYY 102-105
        Q8TMM 106-107           Q8TDD 108-109           Q8TYY 110-113
        Q9A 114-115             Q9B 116-117             Q9C 118-119
        Q9D 120-121             Q10A 122-123            Q11A 124-125
        Q10B 126-127            Q11B 128-129            Q10C 130-131
        Q11C 132-133            Q10D 134-135            Q11D 136-137
        Q10E 138-139            Q10ES 140-141           Q11E 142-143
        Q12A 144-146            Q12B 147-148            Q12C 149-151
        Q13A 152-155            Q13B 156-159            Q13C 160-163
        Q14 164-165             Q15A 166-167            Q15AU 168-169
        Q15B 170-172            Q15BU 173-174           Q15C 175-177
        Q15CU 178-179           Q16FMM 180-181          Q16FDD 182-183
        Q16FYY 184-187          Q16TMM 188-189          Q16TDD 190-191
        Q16TYY 192-195          Q17A 196-197            Q17B 198-199
        Q17C 200-203 .1         Q17D 204-207 .1         Q18A 208-209
        Q19A 210-211            Q18B 212-213            Q19B 214-217 .1
        Q18C 218-219            Q19C 220-222            Q18D 223-224
        Q19D 225-227            Q18E 228-229            Q18ES 230-231
        Q19E 232-236 .1         Q20 237-240             Q21 241-246 .1
        Q21U 247-248            Q22FMM 249-250          Q22FDD 251-252
        Q22FYY 253-256          Q22TMM 257-258          Q22TDD 259-260
        Q22TYY 261-264          Q23A 265-269 .2         Q23B 270-274 .2
        Q24A 275-276            Q25A 277-280 .1         Q24B 281-282
        Q25B 283-286 .1         Q24C 287-288            Q25C 289-292 .1
        Q24D 293-294            Q25D 295-298 .1         Q24E 299-300
        Q24ES 301-302           Q25E 303-307 .2         Q26 308-311 .1
        Q27 312-315             Q28 316-321 .2          Q28U 322-323
        Q29 324-325             Q30 326-327             Q31 328-330
        Q31U 331-332            Q32FMM 333-334          Q32FDD 335-336
        Q32FYY 337-340          Q32TMM 341-342          Q32TDD 343-344
        Q32TYY 345-348          Q33A 349-354 .2         Q33B 355-360 .2
        Q34A 361-362            Q35A 363-366 .1         Q34B 367-368
        Q35B 369-372 .1         Q34C 373-374            Q35C 375-379 .1
        Q34D 380-381            Q35D 382-383            Q34E 384-385
        Q34ES 386-387           Q35E 388-392 .2         Q36 393-394
        Q37 395-398 .1          Q38 399-404 .2          Q39 405-410 .2
        Q40A 411-412            Q40B 413-414            Q40C 415-416
        Q41 417-418             Q42A 419-420            Q42B 421-422
        Q42C 423-424            Q42D 425-426            Q42E 427-428
        Q42F 429-430            Q42G 431-432            Q42H 433-434
        Q42I 435-436            Q42J 437-438            Q43 439-440
        Q44 441-442             Q45 443-444             Q45B 445-447
        Q45C 448-449            Q46 450-451             Q46OTH1 452-453
        Q46OTH2 454-455         Q46OTH3 456-457         Q47BOX 458-459
        R9A1 460-464 .2         R9B1 465-468 .1         R9C1 469-472 .1
        R9D1 473-477 .2         R9E1 478-482 .2         R9F1 483-487 .2
        R9G1 488-491 .1         R9H1 492-496 .2         R9I1 497-502 .2
        R9A2 503-504            R9B2 505-506            R9C2 507-508
        R9D2 509-510            R9E2 511-514 .1         R9F2 515-516
        R9G2 517-518            R9H2 519-520            R9I2 521-524 .1
        R9A3 525-526            R9B3 527-528            R9C3 529-530
        R9D3 531-532            R9E3 533-534            R9F3 535-536
        R9G3 537-538            R9H3 539-542 .1         R9I3 543-546 .1
        Q47AW 547-552 .2        Q47BW 553-559 .2        Q47CW 560-565 .1
        Q47DW 566-570 .1        Q47EW 571-576 .2        Q47FW 577-581 .1
        Q47GW 582-587 .1        Q47HW 588-593 .1        Q47IW 594-600 .2
        BOXE 601-602            Q48A 603-604            Q48B 605-606
        Q48C 607-609            Q48D 610-611            Q48E 612-614
        Q49A 615-623 .2         Q49AU 624-625           Q50A 626-627
        Q49B 628-635 .2         Q49BU 636-643 .2        Q50B 644-651 .2
        Q49C 652-659 .2         Q49CU 660-667 .2        Q50C 668-675 .2
        Q49D 676-683 .2         Q49DU 684-691 .2        Q50D 692-699 .2
        Q49E 700-707 .2         Q49EU 708-715 .2        Q50E 716-723 .2
        Q49F 724-731 .2         Q49FU 732-739 .2        Q50F 740-747 .2
        Q49G 748-755 .2         Q49GU 756-763 .2        Q50G 764-771 .2
        Q49H 772-779 .2         Q49HU 780-781           Q50H 782-783
        Q51A 784-785            Q51APC 786-788          Q51B 789-790
        Q51BPC 791-793          Q51C 794-795            Q51CPC 796-800 .1
        Q51D 801-802            Q51DPC 803-805          Q51E 806-807
        Q51EPC 808-813 .2       Q51F 814-815            Q51FPC 816-821 .2
        Q51G 822-823            Q51GPC 824-829 .2       Q51H 830-831
        Q51HPC 832-837 .2       Q51I 838-839            Q51IPC 840-844 .1
        Q51J 845-846            Q51JPC 847-849          Q51K 850-851
        Q51KPC 852-856 .1       Q51L 857-858            Q51LPC 859-863 .1
        Q51M 864-865            Q51MPC 866-870 .1       Q51N 871-872
        Q51NPC 873-877 .1       Q51O 878-879            Q51OPC 880-884 .1
        Q51P 885-886            Q51PPC 887-889          Q51Q 890-891
        Q51QPC 892-896 .1       Q51R 897-898            Q51RPC 899-901
        Q52 902-909             Q53FMM 910-911          Q53FDD 912-913
        Q53FYY 914-917          Q53TMM 918-919          Q53TDD 920-921
        Q53TYY 922-925          Q54BOX 926-927          Q54PC 928-929
        Q55 930-938             Q56BOX 939-940          Q56PC 941-942
        TMEH 943-944            TMEM 945-946            TMEAP 947-948
        Q57FMM 949-950          Q57FDD 951-952          Q57FYY 953-956
        Q57TMM 957-958          Q57TDD 959-960          Q57TYY 961-964
        Q57A01 965-966          Q57B01N 967-968         Q57B01P 969-970
        Q57A02 971-972          Q57B02N 973-974         Q57B02P 975-976
        Q57A03 977-978          Q57B03N 979-980         Q57B03P 981-982
        Q57A04 983-984          Q57B04N 985-986         Q57B04P 987-988
        Q57A05 989-990          Q57B05N 991-992         Q57B05P 993-994
        Q57A06 995-996          Q57B06N 997-998         Q57B06P 999-1000
        Q57A07 1001-1002        Q57B07N 1003-1005       Q57B07P 1006-1008
        Q57A08 1009-1010        Q57B08N 1011-1012       Q57B08P 1013-1015
        Q57A09 1016-1017        Q57A09S 1018-1019       Q57B09N 1020-1021
        Q57B09P 1022-1023       Q57A10 1024-1025        Q57B10N 1026-1027
        Q57B10P 1028-1029       Q57BTN 1030-1033        Q58FMM 1034-1035
        Q58FDD 1036-1037        Q58FYY 1038-1041        Q58TMM 1042-1043
        Q58TDD 1044-1045        Q58TYY 1046-1049        Q58A01 1050-1051
        Q58B01N 1052-1054       Q58B01P 1055-1056       Q58A02 1057-1058
        Q58B02N 1059-1060       Q58B02P 1061-1062       Q58A03 1063-1064
        Q58B03N 1065-1066       Q58B03P 1067-1068       Q58A04 1069-1070
        Q58B04N 1071-1073       Q58B04P 1074-1076       Q58A05 1077-1078
        Q58B05N 1079-1081       Q58B05P 1082-1083       Q58A06 1084-1085
        Q58B06N 1086-1087       Q58B06P 1088-1089       Q58A07 1090-1091
        Q58B07N 1092-1094       Q58B07P 1095-1097       Q58A08 1098-1099
        Q58B08N 1100-1101       Q58B08P 1102-1104       Q58A09 1105-1106
        Q58A09S 1107-1108       Q58B09N 1109-1110       Q58B09P 1111-1113
        Q58A10 1114-1115        Q58B10N 1116-1117       Q58B10P 1118-1119
        Q58BTN 1120-1123        Q59FMM 1124-1125        Q59FDD 1126-1127
        Q59FYY 1128-1131        Q59TMM 1132-1133        Q59TDD 1134-1135
        Q59TYY 1136-1139        Q59A01 1140-1141        Q59B01N 1142-1144
        Q59B01P 1145-1147       Q59A02 1148-1149        Q59B02N 1150-1151
        Q59B02P 1152-1153       Q59A03 1154-1155        Q59B03N 1156-1157
        Q59B03P 1158-1159       Q59A04 1160-1161        Q59B04N 1162-1164
        Q59B04P 1165-1166       Q59A05 1167-1168        Q59B05N 1169-1171
        Q59B05P 1172-1173       Q59A06 1174-1175        Q59B06N 1176-1177
        Q59B06P 1178-1179       Q59A07 1180-1181        Q59B07N 1182-1184
        Q59B07P 1185-1187       Q59A08 1188-1189        Q59B08N 1190-1191
        Q59B08P 1192-1193       Q59A09 1194-1195        Q59A09S 1196-1197
        Q59B09N 1198-1199       Q59B09P 1200-1201       Q59A10 1202-1203
        Q59B10N 1204-1205       Q59B10P 1206-1207       Q59BTN 1208-1211
        Q60 1212-1217           Q61FMM 1218-1219        Q61FDD 1220-1221
        Q61FYY 1222-1225        Q61TMM 1226-1227        Q61TDD 1228-1229
        Q61TYY 1230-1233        Q61A01 1234-1235        Q61B01N 1236-1238
        Q61B01P 1239-1241       Q61A02 1242-1243        Q61B02N 1244-1246
        Q61B02P 1247-1248       Q61A03 1249-1250        Q61B03N 1251-1253
        Q61B03P 1254-1256       Q61A04 1257-1258        Q61B04N 1259-1261
        Q61B04P 1262-1264       Q61A05 1265-1266        Q61B05N 1267-1269
        Q61B05P 1270-1272       Q61A06 1273-1274        Q61B06N 1275-1276
        Q61B06P 1277-1278       Q61A07 1279-1280        Q61B07N 1281-1283
        Q61B07P 1284-1286       Q61A08 1287-1288        Q61B08N 1289-1290
        Q61B08P 1291-1293       Q61A09 1294-1295        Q61A09S 1296-1297
        Q61B09N 1298-1299       Q61B09P 1300-1301       Q61A10 1302-1303
        Q61B10N 1304-1306       Q61B10P 1307-1308       Q61BTN 1309-1312
        BIG_N 1313-1316         SMALL_N 1317-1318       BIGNT 1319-1321
        SMALLNT 1322-1323       PSUTYPE2 1324-1325      COMPWT62 1326-1333 .4
        CENREG 1334-1335        PH1FW0 1336-1342 .4     PAIR90 1343-1344
        PH2CFW 1345-1351 .4     F2BWA0 1352-1359 .4     VST_PSU 1360-1361
        VUN_PSU 1362-1363       CTCLIENT 1364-1365      FACTYPE 1366-1367
        TRIMFAC0 1368-1373 .4   CTRLCAT2 1374-1375      FTOTCNT 1376-1379
        FSMPCNT 1380-1382       PSF 1383-1388 .4        F2FWA1 1389-1397 .4
        F2FWA2 1398-1405 .4     F2FWA3 1406-1413 .4     F2FWA4 1414-1421 .4
        F2FWA5 1422-1429 .4     F2FWA6 1430-1437 .4     F2FWA7 1438-1445 .4
        F2FWA8 1446-1453 .4     F2FWA9 1454-1461 .4     F2FWA10 1462-1469 .4
        F2FWA11 1470-1477 .4    F2FWA12 1478-1485 .4    F2FWA13 1486-1493 .4
        F2FWA14 1494-1501 .4    F2FWA15 1502-1509 .4    F2FWA16 1510-1517 .4
        F2FWA17 1518-1525 .4    F2FWA18 1526-1533 .4    F2FWA19 1534-1541 .4
        F2FWA20 1542-1549 .4    F2FWA21 1550-1557 .4    F2FWA22 1558-1565 .4
        F2FWA23 1566-1573 .4    F2FWA24 1574-1581 .4    F2FWA25 1582-1589 .4
        F2FWA26 1590-1597 .4    F2FWA27 1598-1605 .4    F2FWA28 1606-1613 .4
        F2FWA29 1614-1621 .4    F2FWA30 1622-1629 .4    F2FWA31 1630-1637 .4
        F2FWA32 1638-1645 .4    F2FWA33 1646-1653 .4    F2FWA34 1654-1661 .4
        F2FWA35 1662-1669 .4    F2FWA36 1670-1677 .4    F2FWA37 1678-1685 .4
        F2FWA38 1686-1693 .4    F2FWA39 1694-1701 .4    F2FWA40 1702-1709 .4
        F2FWA41 1710-1717 .4    F2FWA42 1718-1725 .4    F2FWA43 1726-1733 .4
        F2FWA44 1734-1741 .4    F2FWA45 1742-1749 .4    F2FWA46 1750-1757 .4
        F2FWA47 1758-1765 .4    F2FWA48 1766-1773 .4    F2FWA49 1774-1781 .4
        F2FWA50 1782-1789 .4    F2FWA51 1790-1797 .4    F2FWA52 1798-1805 .4
        F2FWA53 1806-1813 .4    F2FWA54 1814-1821 .4    F2FWA55 1822-1829 .4
        F2FWA56 1830-1837 .4    F2FWA57 1838-1845 .4    F2FWA58 1846-1853 .4
        F2FWA59 1854-1861 .4    F2FWA60 1862-1869 .4    F2FWA61 1870-1877 .4
        F2FWA62 1878-1885 .4    F2FWA63 1886-1893 .4    F2FWA64 1894-1901 .4
        F2FWA65 1902-1909 .4    F2FWA66 1910-1917 .4    F2FWA67 1918-1925 .4
        F2FWA68 1926-1933 .4    F2FWA69 1934-1941 .4    F2FWA70 1942-1949 .4
        F2FWA71 1950-1957 .4    F2FWA72 1958-1965 .4    F2FWA73 1966-1973 .4
        F2FWA74 1974-1981 .4    F2FWA75 1982-1989 .4    F2FWA76 1990-1997 .4
        F2FWA77 1998-2005 .4    F2FWA78 2006-2013 .4    F2FWA0 2014-2021 .4
        TFACRAKE 2022-2027 .4   QFSTRAT 2028-2029       STUDYIND 2030-2031
        FIELDPSU 2032-2034      OWN 2035-2036           ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'CASE IDENTIFICATION NUMBER'
   FACID   = 'NEW FACILITY ID'
   Q1      = 'Q1.  TOTAL CLIENTS CURRENTLY IN S.A. TX AT THIS FACILITY'
   Q2A     = 'Q2A. OFFER HOSPITAL INPATIENT TX'
   Q2B     = 'Q2B. OFFER NON-HOSPITAL RESIDENTIAL TX'
   Q2C     = 'Q2C. OFFER OUTPATIENT METHADONE TX'
   Q2D     = 'Q2D. OFFER OUTPATIENT NON-METHADONE TX'
   Q3A     = 'Q3A. HOW MANY HOSPITAL INPATIENT CLIENTS'
   Q3B     = 'Q3B. HOW MANY NON-HOSPITAL CLIENTS'
   Q3C     = 'Q3C. HOW MANY OUTPATIENT METHADONE CLIENTS'
   Q3D     = 'Q3D. HOW MANY OUTPATIENT CLIENTS'
   Q3TOT   = 'Q3TOT. TOTAL NUMBER OF CLIENTS'
   Q4A     = 'Q4A.  COPY AUDITED FINANCIAL STATEMENTS (MOST CURRENT)'
   Q4B     = 'Q4B. DETAILED ORGANIZATIONAL CHART'
   Q4C     = 'Q4C. ANNUAL STATISTICAL REPORT'
   Q4D     = 'Q4D. YEAR-END G/L SUMMARY REPORT'
   Q4E     = 'Q4E. METHADONE ANNUAL DISPENSING'
   Q4F     = 'Q4F. PERSONNEL LISTING, INCLUDING'
   Q4G     = 'Q4G. FACILITY AND/OR PROGRAM'
   Q4H     = 'Q4H. COPY OF DISCHARGE POLICY'
   Q4I     = 'Q4I. BLANK CLIENT ADMISSION FORM'
   Q4J     = 'Q4J. BLANK CLIENT DISCHARGE FORM'
   Q4K     = 'Q4K. CLIENT BILL WITH CLIENT'
   BOXA    = 'BOX A. IF HOSPITAL INPATIENT NOT OFFERED'
   BOXB    = 'BOX B. IF RESIDENTIAL CARE IS NOT OFFERED'
   BOXC    = 'BOX C. IF OUTPATIENT METHADONE CARE NOT OFFERED'
   BOXD    = 'BOX D. IF OUTPATIENT NON-METHADONE NOT OFFERED'
   Q5A     = 'Q5A. HOW MANY HOSPITAL INPATIENT BEDS'
   Q5B     = 'Q5B. HOW MANY OF THOSE ARE FOR INPATIENT DETOX'
   Q5C     = 'Q5C. HOW MANY OF THOSE ARE FOR INPATIENT REHAB'
   Q6A     = 'Q6A. HOW MANY HOSPITAL INPATIENT ADM. (12 MOS)'
   Q6B     = 'Q6B. HOW MANY OF THESE WERE FOR INPATIENT DETOX'
   Q6C     = 'Q6C. HOW MANY OF THESE WERE FOR INPATIENT REHAB'
   Q7A     = 'Q7A. DURING THE 12-MONTH PERIOD, AVG. LOS FOR INP. DETOX'
   Q7AU    = 'Q7A. UNIT OF TIME FOR DETOX AVERAGE'
   Q7B     = 'Q7B. DURING THAT PERIOD, AVG. LOS FOR INP. REHAB'
   Q7BU    = 'Q7B. UNIT OF TIME FOR REHAB AVERAGE'
   Q7C     = 'Q7C. AVG. LOS FOR ALL HOSP INP. SUB ABUSE CLIENTS'
   Q7CU    = 'Q7C. UNIT OF TIME FOR AVERAGE STAY NUMBER'
   Q8FMM   = 'Q8. FROM: MONTH'
   Q8FDD   = 'Q8. FROM: DAY'
   Q8FYY   = 'Q8. FROM: YEAR'
   Q8TMM   = 'Q8. THROUGH: MONTH'
   Q8TDD   = 'Q8. THROUGH: DAY'
   Q8TYY   = 'Q8. THROUGH: YEAR'
   Q9A     = 'Q9A. # INDIV. COUNSELING SESSIONS PER WK-INP. DETOX'
   Q9B     = 'Q9B. # INDIV. COUNSELING SESSIONS PER WK-INP. REHAB'
   Q9C     = 'Q9C. # GROUP COUNSELING SESSIONS PER WK-INP. DETOX'
   Q9D     = 'Q9D. # INDIV. COUNSELING SESSIONS PER WK-INP. REHAB'
   Q10A    = 'Q10A.  DO YOU PROVIDE GROUP THERAPY SESSIONS'
   Q11A    = 'Q11A.  HOW MANY IN A TYPICAL GROUP THERAPY SESSION'
   Q10B    = 'Q10B.  DO YOU PROVIDE GROUP EDUCATIONAL SESSIONS'
   Q11B    = 'Q11B.  HOW MANY IN A TYPICAL GROUP EDUCATIONAL SESSION'
   Q10C    = 'Q10C.  DO YOU PROVIDE SELF-HELP GROUP MEETINGS'
   Q11C    = 'Q11C.  HOW MANY IN A TYPICAL SELF-HELP GROUP MEETING'
   Q10D    = 'Q10D.DO YOU PROVIDE COMMUNITY OR GOVERNING SESSIONS'
   Q11D    = 'Q11D.  HOW MANY IN A TYPICAL COMMUNITY OR GOVERNING'
   Q10E    = 'Q10E.  DO YOU PROVIDE OTHER SESSIONS'
   Q10ES   = 'Q10E.  OTHER TYPE OF SESSION SPECIFIED'
   Q11E    = 'Q11E. HOW MANY IN A TYPICAL OTHER SESSION'
   Q12A    = 'Q12A. HOW MANY NON-HOSPITAL RESIDENTIAL BEDS'
   Q12B    = 'Q12B. HOW MANY OF THOSE ARE FOR RES DETOX'
   Q12C    = 'Q12C. HOW MANY OF THOSE ARE FOR RES REHAB'
   Q13A    = 'Q13A. HOW MANY NON-HOSPITAL S.A. TX ADM (12 MOS)'
   Q13B    = 'Q13B. HOW MANY OF THESE WERE FOR RES DETOX'
   Q13C    = 'Q13C. HOW MANY OF THESE WERE FOR RES REHAB'
   Q14     = 'Q14. IS THIS A THERAPEUTIC COMMUNITY'
   Q15A    = 'Q15A. AVG. LOS FOR RES DETOX (DURING 12 MOS)'
   Q15AU   = 'Q15A. UNIT OF TIME FOR DETOX AVERAGE'
   Q15B    = 'Q15B. AVG. LOS FOR RES REHAB (DURING 12 MOS)'
   Q15BU   = 'Q15B. UNIT OF TIME FOR REHAB AVERAGE'
   Q15C    = 'Q15C. AVG. LOS FOR ALL NON-HOSP RES SUB ABUSE CLIENTS'
   Q15CU   = 'Q15C. UNIT OF TIME FOR AVERAGE STAY'
   Q16FMM  = 'Q16. FROM: MONTH'
   Q16FDD  = 'Q16. FROM: DAY'
   Q16FYY  = 'Q16. FROM: YEAR'
   Q16TMM  = 'Q16. THROUGH: MONTH'
   Q16TDD  = 'Q16. THROUGH: DAY'
   Q16TYY  = 'Q16. THROUGH: YEAR'
   Q17A    = 'Q17A. # INDIV. COUNSELING SESSIONS PER WK-RES DETOX'
   Q17B    = 'Q17B. # INDIV. COUNSELING SESSIONS PER WK-RES REHAB'
   Q17C    = 'Q17C. # GROUP COUNSELING SESSIONS PER WK-RES DETOX'
   Q17D    = 'Q17D. # GROUP COUNSELING SESSIONS PER WK-RES REHAB'
   Q18A    = 'Q18A. GROUP THERAPY SESSIONS'
   Q19A    = 'Q19A.  HOW MANY IN A TYPICAL GROUP THERAPY SESSION'
   Q18B    = 'Q18B. GROUP EDUCATIONAL SESSIONS'
   Q19B    = 'Q19B.  HOW MANY IN A TYPICAL GROUP EDUCATIONAL SESSION'
   Q18C    = 'Q18C. SELF-HELP GROUP MEETINGS'
   Q19C    = 'Q19C.  HOW MANY IN A TYPICAL SELF-HELP GROUP MEETING'
   Q18D    = 'Q18D. COMMUNITY OR GOVERNING SESSIONS'
   Q19D    = 'Q19D.  HOW MANY IN A TYPICAL COMM OR GOV SESSION'
   Q18E    = 'Q18E. OTHER SESSIONS'
   Q18ES   = 'Q18E. OTHER TYPE OF SESSION SPECIFIED'
   Q19E    = 'Q19E.  HOW MANY IN A TYPICAL OTHER SESSION'
   Q20     = 'Q20. HOW MANY ADMISSIONS TO OP METH TX (12 MOS)'
   Q21     = 'Q21. AVG LOS FOR OP METH CLIENTS (DURING 12 MOS)'
   Q21U    = 'Q21. UNIT OF TIME FOR AVERAGE STAY'
   Q22FMM  = 'Q22. FROM: MONTH'
   Q22FDD  = 'Q22. FROM: DAY'
   Q22FYY  = 'Q22. FROM: YEAR'
   Q22TMM  = 'Q22. THROUGH: MONTH'
   Q22TDD  = 'Q22. THROUGH: DAY'
   Q22TYY  = 'Q22. THROUGH: YEAR'
   Q23A    = 'Q23A.  # INDIV. COUNSELING SESSIONS PER WK-OP METH'
   Q23B    = 'Q23B.  # GROUP COUNSELING SESSIONS PER WK-OP METH'
   Q24A    = 'Q24A. DO YOU PROVIDE GROUP THERAPY SESSIONS'
   Q25A    = 'Q25A.  HOW MANY IN A TYPICAL GROUP THERAPY SESSION'
   Q24B    = 'Q24B. DO YOU PROVIDE GROUP EDUCATIONAL SESSIONS'
   Q25B    = 'Q25B.  HOW MANY IN A TYPICAL GROUP EDUCATIONAL SESSION'
   Q24C    = 'Q24C.  DO YOU PROVIDE SELF-HELP GROUP MEETINGS'
   Q25C    = 'Q25C.  HOW MANY IN A TYPICAL SELF-HELP GROUP MEETING'
   Q24D    = 'Q24D. DO YOU PROVIDE COMMUNITY OR GOVERNING SESSIONS'
   Q25D    = 'Q25D. HOW MANY IN A TYPICAL COMM OR GOV SESSION'
   Q24E    = 'Q24E. DO YOU PROVIDE OTHER SESSIONS'
   Q24ES   = 'Q24E. OTHER TYPE OF SESSION SPECIFIED'
   Q25E    = 'Q25E.  HOW MANY IN A TYPICAL OTHER SESSION'
   Q26     = 'Q26. AVG DAILY DOSAGE (MG)-CLIENTS ON LEVEL METH DOSAGE'
   Q27     = 'Q27. HOW MANY ADMISSIONS TO OP NON-METH TX (12 MOS)'
   Q28     = 'Q28. AVG LOS FOR OP NON-METH CLIENTS (DURING 12 MOS)'
   Q28U    = 'Q28. UNIT OF TIME FOR AVERAGE STAY'
   Q29     = 'Q29. DOES THIS FACILITY PROVIDE OP DETOX'
   Q30     = 'Q30. ABOUT WHAT % OF ADM FOR DETOX ONLY (DURING 12 MOS)'
   Q31     = 'Q31. AVG LOS FOR DETOX-ONLY CLIENTS (DURING 12 MOS)'
   Q31U    = 'Q31. UNIT OF TIME FOR AVERAGE STAY'
   Q32FMM  = 'Q32. FROM: MONTH'
   Q32FDD  = 'Q32. FROM: DAY'
   Q32FYY  = 'Q32. FROM: YEAR'
   Q32TMM  = 'Q32. THROUGH: MONTH'
   Q32TDD  = 'Q32. THROUGH: DAY'
   Q32TYY  = 'Q32. THROUGH: YEAR'
   Q33A    = 'Q33A. # INDIV. COUNSELING SESSIONS PER WK-OP NON-METH'
   Q33B    = 'Q33B. # GROUP COUNSELING SESSIONS PER WK-OP NON-METH'
   Q34A    = 'Q34A. DO YOU PROVIDE GROUP THERAPY SESSIONS'
   Q35A    = 'Q35A.  HOW MANY IN A TYPICAL GROUP THERAPY SESSION'
   Q34B    = 'Q34B. DO YOU PROVIDE GROUP EDUCATIONAL SESSIONS'
   Q35B    = 'Q35B.  HOW MANY IN A TYPICAL GROUP EDUCATIONAL SESSION'
   Q34C    = 'Q34C. DO YOU PROVIDE SELF-HELP GROUP MEETINGS'
   Q35C    = 'Q35C.  HOW MANY IN A TYPICAL SELF-HELP GROUP MEETING'
   Q34D    = 'Q34D. DO YOU PROVIDE COMMUNITY OR GOVERNING SESSIONS'
   Q35D    = 'Q35D. HOW MANY IN A TYPICAL COMM OR GOV SESSION'
   Q34E    = 'Q34E. DO YOU PROVIDE OTHER SESSIONS'
   Q34ES   = 'Q34E. OTHER TYPE OF SESSION SPECIFIED'
   Q35E    = 'Q35E.  HOW MANY IN A TYPICAL OTHER SESSION'
   Q36     = 'Q36.  DOES THIS FACILITY HAVE AN INTENSIVE OP PROGRAM'
   Q37     = 'Q37. AVG HRS PER WK-IOP CLIENTS ATTEND PROGRAM'
   Q38     = 'Q38. AVG # CLIENTS PER MONTH DROPPED TX BEFORE COMPLETING'
   Q39     = 'Q39. AVG # CLIENTS PER MONTH DROPPED TX AFTER 1 DAY/SESSION'
   Q40A    = 'Q40A. OFFER OUTPATIENT COUNSELING-AFTERCARE'
   Q40B    = 'Q40B. OFFER SELF-HELP GROUPS-AFTERCARE'
   Q40C    = 'Q40C. OFFER ALUMNI GROUPS-AFTERCARE'
   Q41     = 'Q41. FACILITY MAINTAINS ANY COMPUTERIZED TX CLIENT INFO'
   Q42A    = 'Q42A. CLIENT DESCRIPTIVE INFORMATION-COMPUTERIZED INFO'
   Q42B    = 'Q42B. DRUGS OF ABUSE-COMPUTERIZED INFO'
   Q42C    = 'Q42C. CLIENT TREATMENT HISTORY-COMPUTERIZED INFO'
   Q42D    = 'Q42D. DIAGNOSIS-COMPUTERIZED INFO'
   Q42E    = 'Q42E. SERVICES RECEIVED-COMPUTERIZED INFO'
   Q42F    = 'Q42F. # INPAT. BED DAYS -COMPUTERIZED INFO'
   Q42G    = 'Q42G. # OP VISITS OR ENCOUNTERS-COMPUTERIZED INFO'
   Q42H    = 'Q42H. REASONS FOR DISCHARGE-COMPUTERIZED INFO'
   Q42I    = 'Q42I. SOURCE OF PAYMENT-COMPUTERIZED INFO'
   Q42J    = 'Q42J.BILLING INFORMATION-COMPUTERIZED INFO'
   Q43     = 'Q43. COMPUTERIZED CLIENT & BILLING RECORDS LINKABLE?'
   Q44     = 'Q44. ANNUAL AUDITED FINANCIAL STATEMENTS PREPARED'
   Q45     = 'Q45. IS FINANCIAL STATEMENT FOR THIS FACILITY ONLY'
   Q45B    = 'Q45B. HOW MANY OTHER ENTITIES-FINANCIAL STATEMENT'
   Q45C    = 'Q45C. HOW MANY OF THESE PROVIDE S.A. TX-FINANCIAL STATEMENT'
   Q46     = 'Q46. FACILITY RECEIVES IN-KIND CONTRIBUTIONS'
   Q46OTH1 = 'Q46.  FIRST OTHER IN-KIND CONTRIBUTION SPECIFIED'
   Q46OTH2 = 'Q46.  SECOND OTHER IN-KIND CONTRIBUTION SPECIFIED'
   Q46OTH3 = 'Q46.  THIRD OTHER IN-KIND CONTRIBUTION SPECIFIED'
   Q47BOX  = 'CAN ONLY REPORT STAFF NUMBERS AS FTEs'
   R9A1    = 'R9A1. NO. F/T PHYSICIANS (MD/DO, PSYCHIATRISTS)'
   R9B1    = 'R9B1. NO. REGISTERED NURSES (RN)'
   R9C1    = 'R9C1. NO. OTHER MEDICAL (LPN, PA, ETC)'
   R9D1    = 'R9D1. NO. F/T DOCTORAL LEVEL COUNSELORS'
   R9E1    = 'R9E1. NO. F/T MASTERS LEVEL COUNSELORS'
   R9F1    = 'R9F1. NO. F/T OTHER DEGREED COUNSELORS'
   R9G1    = 'R9G1. NO. F/T NON-DEGREED COUNSELORS'
   R9H1    = 'R9H1. NO. F/T ALL OTHER STAFF'
   R9I1    = 'R9I1. TOTAL NUMBER OF FULL-TIME STAFF'
   R9A2    = 'R9A2. NO. P/T PHYSICIANS (MD/DO, PSYCHIATRISTS)'
   R9B2    = 'R9B2. NO. P/T REGISTERED NURSES (RN)'
   R9C2    = 'R9C2. NO. P/T OTHER MEDICAL (LPN, PA, ETC)'
   R9D2    = 'R9D2. NO. P/T DOCTORAL LEVEL COUNSELORS'
   R9E2    = 'R9E2. NO. P/T MASTERS LEVEL COUNSELORS'
   R9F2    = 'R9F2. NO. P/T OTHER DEGREED COUNSELORS'
   R9G2    = 'R9G2. NO. P/T NON-DEGREED COUNSELORS'
   R9H2    = 'R9H2. NO. P/T ALL OTHER STAFF'
   R9I2    = 'R9I2. TOTAL NUMBER OF PART-TIME STAFF'
   R9A3    = 'R9A3. NO. CONTRACT PHYSICIANS'
   R9B3    = 'R9B3. NO. CONTRACT RNS'
   R9C3    = 'R9C3. NO. CONTRACT OTHER MED(LPN,PA,ETC)'
   R9D3    = 'R9D3. NO. CONTRACT DOC LVL COUNSELORS'
   R9E3    = 'R9E3. NO. CONTRACT MA LVL COUNSELORS'
   R9F3    = 'R9F3. NO. CONTRACT OTHER DEGREED COUNSLR'
   R9G3    = 'R9G3. NO. CONTRACT NON-DEGREED COUNSLR'
   R9H3    = 'R9H3. NO. CONTRACT ALL OTHER STAFF'
   R9I3    = 'R9I3. TOTAL NO. CONTRACT/CONSULTANT STAF'
   Q47AW   = 'Q47AW.  ONE -WEEK STAFF HOURS:  PHYSICIANS'
   Q47BW   = 'Q47BW. ONE-WEEK STAFF HOURS: RN''S'
   Q47CW   = 'Q47CW. ONE-WEEK STAFF HOURS: OTHER'
   Q47DW   = 'Q47DW. ONE-WEEK STAFF HOURS: DOCTORAL'
   Q47EW   = 'Q47EW. ONE-WEEK STAFF HOURS: MASTERS'
   Q47FW   = 'Q47FW. ONE-WEEK STAFF HOURS: OTHER'
   Q47GW   = 'Q47GW.  ONE -WEEK STAFF HOURS:  NON-DEGREED COUSELORS'
   Q47HW   = 'Q47HW. ONE-WEEK STAFF HOURS: ALL'
   Q47IW   = 'Q47IW. TOTAL ONE-WEEK STAFF HOURS'
   BOXE    = 'CHECK Q2 ON PAGE 2, IF ONLY ONE TYPE OF CARE = YES'
   Q48A    = 'Q48A.  % STAFF TIME FOR WEEK-HOSP INPATIENT TX'
   Q48B    = 'Q48B.  % STAFF TIME FOR WEEK-NON-HOSP RESIDENTIAL'
   Q48C    = 'Q48C.  % STAFF TIME FOR WEEK-OP SUB ABUSE TX'
   Q48D    = 'Q48D.  % STAFF TIME FOR WEEK-OP METHADONE'
   Q48E    = 'Q48E.  % STAFF TIME FOR WEEK-OP NON-METHADONE'
   Q49A    = 'Q49A.  AVG SALARY-PHYSICIANS'
   Q49AU   = 'Q49A.  UNIT FOR SALARY'
   Q50A    = 'Q50A.  AVG FRINGE BENEFIT RATE-PHYSICIANS'
   Q49B    = 'Q49B.  AVG SALARY-REGISTERED NURSES'
   Q49BU   = 'Q49B.  UNIT FOR SALARY'
   Q50B    = 'Q50B.  AVG FRINGE BENEFIT RATE-RNS'
   Q49C    = 'Q49C.  AVG SALARY-OTHER MEDICAL PERSONNEL'
   Q49CU   = 'Q49C.  UNIT FOR SALARY'
   Q50C    = 'Q50C.  AVG FRINGE BENEFIT RATE-OTHER MEDICAL PERSONNEL'
   Q49D    = 'Q49D.  AVG SALARY-DOCTORAL LEVEL COUNSELORS'
   Q49DU   = 'Q49D.  UNIT FOR SALARY'
   Q50D    = 'Q50D.  AVG FRINGE BENEFIT RATE-DOCTORAL LEVEL COUNSELORS'
   Q49E    = 'Q49E.  AVG SALARY-MASTERS LEVEL COUNSELORS'
   Q49EU   = 'Q49E.  UNIT FOR SALARY'
   Q50E    = 'Q50E.  AVG FRINGE BENEFIT RATE-MASTERS LEVEL COUNSELORS'
   Q49F    = 'Q49F.  AVG SALARY-OTHER DEGREED COUNSELORS'
   Q49FU   = 'Q49F.  UNIT FOR SALARY'
   Q50F    = 'Q50F.  AVG FRINGE BENEFIT RATE-OTHER DEGREED COUNSELORS'
   Q49G    = 'Q49G.  AVG SALARY-NON-DEGREED COUNSELORS'
   Q49GU   = 'Q49G.  UNIT FOR SALARY'
   Q50G    = 'Q50G.  AVG FRINGE BENEFIT RATE-NON-DEGREED COUNSELORS'
   Q49H    = 'Q49H.  AVG SALARY-ALL OTHER STAFF'
   Q49HU   = 'Q49H.  UNIT FOR SALARY'
   Q50H    = 'Q50H.  AVG FRINGE BENEFIT RATE-ALL OTHER STAFF'
   Q51A    = 'Q51A.  OFFERED COMPREHENSIVE ASSESSMENT/DIAGNOSIS'
   Q51APC  = 'Q51A.  % CLIENTS REC''D ASSESSMENT/DIAGNOSIS'
   Q51B    = 'Q51B.  OFFERED CHILD CARE'
   Q51BPC  = 'Q51B.  % CLIENTS REC''D CHILD CARE'
   Q51C    = 'Q51C.  OFFERED TRANSPORTATION'
   Q51CPC  = 'Q51C.  % CLIENTS REC''D TRANSPORTATION'
   Q51D    = 'Q51D.  OFFERED SELF-HELP OR MUTUAL-HELP GROUPS'
   Q51DPC  = 'Q51D.  % CLIENTS REC''D SELF- OR MUTUAL-HELP GROUPS'
   Q51E    = 'Q51E.  OFFERED INDIVIDUAL THERAPY'
   Q51EPC  = 'Q51E.  % CLIENTS REC''D INDIVIDUAL THERAPY'
   Q51F    = 'Q51F.  OFFERED GROUP THERAPY, NOT RELAPSE PREV'
   Q51FPC  = 'Q51F.  % CLIENTS REC''D GROUP THERAPY'
   Q51G    = 'Q51G.  OFFERED RELAPSE PREVENTION GROUPS'
   Q51GPC  = 'Q51G.  % CLIENTS REC''D RELAPSE PREVENTION GROUPS'
   Q51H    = 'Q51H.  OFFERED FAMILY COUNSELING'
   Q51HPC  = 'Q51H.  % CLIENTS REC''D FAMILY COUNSELING'
   Q51I    = 'Q51I.  OFFERED EMPLOYMENT COUNSELING/TRAINING'
   Q51IPC  = 'Q51I.  % CLIENTS REC''D COUNSELING/TRAINING'
   Q51J    = 'Q51J.  OFFERED ACADEMIC EDUCATION/GED CLASSES'
   Q51JPC  = 'Q51J.  % CLIENTS REC''D ACADEMIC EDUCATION/GED CLASSE'
   Q51K    = 'Q51K.  OFFERED HIV/AIDS EDUCATION/COUNSELING/SUPPORT'
   Q51KPC  = 'Q51K.  % CLIENTS REC''D HIV/AIDS ED/COUNSELING/SUPPORT'
   Q51L    = 'Q51L.  OFFERED COMBINED SUB ABUSE & MENTAL HEALTH TX'
   Q51LPC  = 'Q51L.  % CLIENTS REC''D COMBINED SUB ABUSE & MH TX'
   Q51M    = 'Q51M.  OFFERED TB SCREENING'
   Q51MPC  = 'Q51M.  % CLIENTS REC''D TB SCREENING'
   Q51N    = 'Q51N.  OFFERED PRENATAL CARE'
   Q51NPC  = 'Q51N.  % CLIENTS REC''D PRENATAL CARE'
   Q51O    = 'Q51O.  OFFERED SMOKING CESSATION'
   Q51OPC  = 'Q51O.  % CLIENTS REC''D SMOKING CESSATION'
   Q51P    = 'Q51P.  OFFERED ACUPUNCTURE'
   Q51PPC  = 'Q51P.  % CLIENTS REC''D ACUPUNCTURE'
   Q51Q    = 'Q51Q.  OFFERED AFTERCARE'
   Q51QPC  = 'Q51Q.  % CLIENTS REC''D AFTERCARE'
   Q51R    = 'Q51R.  OFFERED OUTCOME FOLLOWUP'
   Q51RPC  = 'Q51R.  % CLIENTS REC''D OUTCOME FOLLOWUP'
   Q52     = 'Q52. 12-MONTH SA TX REVENUE'
   Q53FMM  = 'Q53. FROM: MONTH'
   Q53FDD  = 'Q53. FROM: DAY'
   Q53FYY  = 'Q53. FROM: YEAR'
   Q53TMM  = 'Q53. THROUGH: MONTH'
   Q53TDD  = 'Q53. THROUGH: DAY'
   Q53TYY  = 'Q53. THROUGH: YEAR'
   Q54BOX  = 'RESPONDENT UNABLE TO REPORT REVENUE/FUNDING'
   Q54PC   = 'Q54PC. ESTIMATED % REVENUE RELATED TO SUB ABUSE TX'
   Q55     = 'Q55. WHAT ARE THE 12-MONTH TOTAL SUB ABUSE TX COSTS'
   Q56BOX  = 'Q56 BOX. IF RESPONDENT IS UNABLE TO REPORT COSTS'
   Q56PC   = 'Q56PC. ESTIMATED % TOT COSTS RELATED TO SUB ABUSE TX'
   TMEH    = 'TIME ENDED: HOUR'
   TMEM    = 'TIME ENDED: MINUTE'
   TMEAP   = 'TIME ENDED: AM OR PM'
   Q57FMM  = 'Q57. FROM: MONTH'
   Q57FDD  = 'Q57. FROM: DAY'
   Q57FYY  = 'Q57. FROM: YEAR'
   Q57TMM  = 'Q57. THROUGH: MONTH'
   Q57TDD  = 'Q57. THROUGH: DAY'
   Q57TYY  = 'Q57. THROUGH: YEAR'
   Q57A01  = 'Q57A_1. HOSP INPAT PRIM PAY: CLIENT SELF PAYMENT'
   Q57B01N = 'Q57B_1N. # ADM-PRIMARILY CLIENT SELF PAYMENT'
   Q57B01P = 'Q57B_1P. % ADM-PRIMARILY CLIENT SELF PAYMENT'
   Q57A02  = 'Q57A_2. HOSP INPAT PRIM PAY: PRIV INS, FEE-FOR-SERVICE'
   Q57B02N = 'Q57B_2N. # ADM-PRIMARILY PRIV INS, FEE-FOR-SERVICE'
   Q57B02P = 'Q57B_2P. % ADM-PRIMARILY PRIV INS, FEE-FOR-SERVICE'
   Q57A03  = 'Q57A_3. HOSP INPAT PRIM PAY: HMO/PPO/MGD CARE'
   Q57B03N = 'Q57B_3N. # ADM-PRIMARILY THIS HMO/PPO/MGD CARE'
   Q57B03P = 'Q57B_3P. % ADM-PRIMARILY THIS HMO/PPO/MGD CARE'
   Q57A04  = 'Q57A_4. HOSP INPAT PRIM PAY: CRIMINAL JUSTICE SYSTEM'
   Q57B04N = 'Q57B_4N. # ADM-PRIMARILY CRIMINAL JUSTICE SYSTEM'
   Q57B04P = 'Q57B_4P. % ADM-PRIMARILY CRIMINAL JUSTICE SYSTEM'
   Q57A05  = 'Q57A_5. HOSP INPAT PRIM PAY: MEDICAID'
   Q57B05N = 'Q57B_5N. # ADM-PRIMARILY MEDICAID'
   Q57B05P = 'Q57B_5P. % ADM-PRIMARILY MEDICAID'
   Q57A06  = 'Q57A_6. HOSP INPAT PRIM PAY: MEDICARE'
   Q57B06N = 'Q57B_6N. # ADM-PRIMARILY MEDICARE'
   Q57B06P = 'Q57B_6P. % ADM-PRIMARILY MEDICARE'
   Q57A07  = 'Q57A_7. HOSP INPAT PRIM PAY: OTHER PUBLIC PAYMENT'
   Q57B07N = 'Q57B_7N. # ADM-PRIMARILY OTHER PUBLIC PAYMENT'
   Q57B07P = 'Q57B_7P. % ADM-PRIMARILY OTHER PUBLIC PAYMENT'
   Q57A08  = 'Q57A_8. HOSP INPAT PRIM PAY: NO PAYMENT'
   Q57B08N = 'Q57B_8N. # ADM-PRIMARILY NO PAYMENT'
   Q57B08P = 'Q57B_8P. % ADM-PRIMARILY NO PAYMENT'
   Q57A09  = 'Q57A_9. HOSP INPAT PRIM PAY: OTHER/SPECIFY LARGEST TYPE'
   Q57A09S = 'Q57A_9S. OTHER PRIMARY PAYMENT TYPE SPECIFIED'
   Q57B09N = 'Q57B_9N. # ADM-PRIMARILY OTHER/SPECIFY LARGEST TYPE'
   Q57B09P = 'Q57B_9P. % ADM-PRIMARILY OTHER/SPECIFY LARGEST TYPE'
   Q57A10  = 'Q57A_10. HOSP INPAT PRIM PAY: UNKNOWN'
   Q57B10N = 'Q57B_10N. # ADM-PRIMARILY UNKNOWN'
   Q57B10P = 'Q57B_10P. % ADM-PRIMARILY UNKNOWN'
   Q57BTN  = 'Q57B_TN.  TOTAL NUMBER OF ADMISSIONS (COPIED FROM Q6A)'
   Q58FMM  = 'Q58. FROM: MONTH'
   Q58FDD  = 'Q58. FROM: DAY'
   Q58FYY  = 'Q58. FROM: YEAR'
   Q58TMM  = 'Q58. THROUGH: MONTH'
   Q58TDD  = 'Q58. THROUGH: DAY'
   Q58TYY  = 'Q58. THROUGH: YEAR'
   Q58A01  = 'Q58A_1. NON-HOSP RES PRIM PAY: CLIENT SELF PAYMENT'
   Q58B01N = 'Q58B_1N. # ADM-PRIMARILY CLIENT SELF PAYMENT'
   Q58B01P = 'Q58B_1P. % ADM-PRIMARILY CLIENT SELF PAYMENT'
   Q58A02  = 'Q58A_2. NON-HOSP RES PRIM PAY: PRIV INS, FEE-FOR-SERVICE'
   Q58B02N = 'Q58B_2N. # ADM-PRIMARILY PRIV INS, FEE-FOR-SERVICE'
   Q58B02P = 'Q58B_2P. % ADM-PRIMARILY PRIV INS, FEE-FOR-SERVICE'
   Q58A03  = 'Q58A_3. NON-HOSP RES PRIM PAY: HMO/PPO/MGD CARE'
   Q58B03N = 'Q58B_3N. # ADM-PRIMARILY THIS HMO/PPO/MGD CARE'
   Q58B03P = 'Q58B_3P. % ADM-PRIMARILY THIS HMO/PPO/MGD CARE'
   Q58A04  = 'Q58A_4. NON-HOSP RES PRIM PAY: CRIMINAL JUSTICE SYSTEM'
   Q58B04N = 'Q58B_4N. # ADM-PRIMARILY CRIMINAL JUSTICE SYSTEM'
   Q58B04P = 'Q58B_4P. % ADM-PRIMARILY CRIMINAL JUSTICE SYSTEM'
   Q58A05  = 'Q58A_5. NON-HOSP RES PRIM PAY: MEDICAID'
   Q58B05N = 'Q58B_5N. # ADM-PRIMARILY MEDICAID'
   Q58B05P = 'Q58B_5P. % ADM-PRIMARILY MEDICAID'
   Q58A06  = 'Q58A_6. NON-HOSP RES PRIM PAY: MEDICARE'
   Q58B06N = 'Q58B_6N. # ADM-PRIMARILY MEDICARE'
   Q58B06P = 'Q58B_6P. % ADM-PRIMARILY MEDICARE'
   Q58A07  = 'Q58A_7. NON-HOSP RES PRIM PAY: OTHER PUBLIC PAYMENT'
   Q58B07N = 'Q58B_7N. # ADM-PRIMARILY OTHER PUBLIC PAYMENT'
   Q58B07P = 'Q58B_7P. % ADM-PRIMARILY OTHER PUBLIC PAYMENT'
   Q58A08  = 'Q58A_8. NON-HOSP RES PRIM PAY: NO PAYMENT'
   Q58B08N = 'Q58B_8N. # ADM-PRIMARILY NO PAYMENT'
   Q58B08P = 'Q58B_8P. % ADM-PRIMARILY NO PAYMENT'
   Q58A09  = 'Q58A_9. NON-HOSP RES PRIM PAY: OTHER/SPECIFY LARGEST TYPE'
   Q58A09S = 'Q58A_9S. OTHER PRIMARY PAYMENT TYPE SPECIFIED'
   Q58B09N = 'Q58B_9N. # ADM-PRIMARILY OTHER/SPECIFY LARGEST TYPE'
   Q58B09P = 'Q58B_9P. % ADM-PRIMARILY OTHER/SPECIFY LARGEST TYPE'
   Q58A10  = 'Q58A_10. NON-HOSP RES PRIM PAY: UNKNOWN'
   Q58B10N = 'Q58B_10N. # ADM-PRIMARILY UNKNOWN'
   Q58B10P = 'Q58B_10P. % ADM-PRIMARILY UNKNOWN'
   Q58BTN  = 'Q58B_TN.  TOTAL NUMBER OF ADMISSIONS (COPIED FROM Q13A)'
   Q59FMM  = 'Q59. FROM: MONTH'
   Q59FDD  = 'Q59. FROM: DAY'
   Q59FYY  = 'Q59. FROM: YEAR'
   Q59TMM  = 'Q59. THROUGH: MONTH'
   Q59TDD  = 'Q59. THROUGH: DAY'
   Q59TYY  = 'Q59. THROUGH: YEAR'
   Q59A01  = 'Q59A_1. OP METH PRIM PAY: CLIENT SELF PAYMENT'
   Q59B01N = 'Q59B_1N. # ADM-PRIMARILY CLIENT SELF PAYMENT'
   Q59B01P = 'Q59B_1P. % ADM-PRIMARILY CLIENT SELF PAYMENT'
   Q59A02  = 'Q59A_2. OP METH PRIM PAY: PRIV INS, FEE-FOR-SERVICE'
   Q59B02N = 'Q59B_2N. # ADM-PRIMARILY PRIV INS, FEE-FOR-SERVICE'
   Q59B02P = 'Q59B_2P. % ADM-PRIMARILY PRIV INS, FEE-FOR-SERVICE'
   Q59A03  = 'Q59A_3. OP METH PRIM PAY: HMO/PPO/MGD CARE'
   Q59B03N = 'Q59B_3N. # ADM-PRIMARILY THIS HMO/PPO/MGD CARE'
   Q59B03P = 'Q59B_3P. % ADM-PRIMARILY THIS HMO/PPO/MGD CARE'
   Q59A04  = 'Q59A_4. OP METH PRIM PAY: CRIMINAL JUSTICE SYSTEM'
   Q59B04N = 'Q59B_4N. # ADM-PRIMARILY CRIMINAL JUSTICE SYSTEM'
   Q59B04P = 'Q59B_4P. % ADM-PRIMARILY CRIMINAL JUSTICE SYSTEM'
   Q59A05  = 'Q59A_5. OP METH PRIM PAY: MEDICAID'
   Q59B05N = 'Q59B_5N. # ADM-PRIMARILY MEDICAID'
   Q59B05P = 'Q59B_5P. % ADM-PRIMARILY MEDICAID'
   Q59A06  = 'Q59A_6. OP METH PRIM PAY: MEDICARE'
   Q59B06N = 'Q59B_6N. # ADM-PRIMARILY MEDICARE'
   Q59B06P = 'Q59B_6P. % ADM-PRIMARILY MEDICARE'
   Q59A07  = 'Q59A_7. OP METH PRIM PAY: OTHER PUBLIC PAYMENT'
   Q59B07N = 'Q59B_7N. # ADM-PRIMARILY OTHER PUBLIC PAYMENT'
   Q59B07P = 'Q59B_7P. % ADM-PRIMARILY OTHER PUBLIC PAYMENT'
   Q59A08  = 'Q59A_8. OP METH PRIM PAY: NO PAYMENT'
   Q59B08N = 'Q59B_8N. # ADM-PRIMARILY NO PAYMENT'
   Q59B08P = 'Q59B_8P. % ADM-PRIMARILY NO PAYMENT'
   Q59A09  = 'Q59A_9. OP METH PRIM PAY: OTHER/SPECIFY LARGEST TYPE'
   Q59A09S = 'Q59A_9S. OTHER PRIMARY PAYMENT TYPE SPECIFIED'
   Q59B09N = 'Q59B_9N. # ADM-PRIMARILY OTHER/SPECIFY LARGEST TYPE'
   Q59B09P = 'Q59B_9P. % ADM-PRIMARILY OTHER/SPECIFY LARGEST TYPE'
   Q59A10  = 'Q59A_10. OP METH PRIM PAY: UNKNOWN'
   Q59B10N = 'Q59B_10N. # ADM-PRIMARILY UNKNOWN'
   Q59B10P = 'Q59B_10P. % ADM-PRIMARILY UNKNOWN'
   Q59BTN  = 'Q59B_TN.  TOTAL NUMBER OF ADMISSIONS (COPIED FROM Q20)'
   Q60     = 'Q60.  WHAT WAS THE TOTAL COST OF METHADONE DISPENSED'
   Q61FMM  = 'Q61. FROM: MONTH'
   Q61FDD  = 'Q61. FROM: DAY'
   Q61FYY  = 'Q61. FROM: YEAR'
   Q61TMM  = 'Q61. THROUGH: MONTH'
   Q61TDD  = 'Q61. THROUGH: DAY'
   Q61TYY  = 'Q61. THROUGH: YEAR'
   Q61A01  = 'Q61A_1. OP NON-METH PRIM PAY: CLIENT SELF PAYMENT'
   Q61B01N = 'Q61B_1N. # ADM-PRIMARILY CLIENT SELF PAYMENT'
   Q61B01P = 'Q61B_1P. % ADM-PRIMARILY CLIENT SELF PAYMENT'
   Q61A02  = 'Q61A_2. OP NON-METH PRIM PAY: PRIV INS, FEE-FOR-SERVICE'
   Q61B02N = 'Q61B_2N. # ADM-PRIMARILY PRIV INS, FEE-FOR-SERVICE'
   Q61B02P = 'Q61B_2P. % ADM-PRIMARILY PRIV INS, FEE-FOR-SERVICE'
   Q61A03  = 'Q61A_3. OP NON-METH PRIM PAY: HMO/PPO/MGD CARE'
   Q61B03N = 'Q61B_3N. # ADM-PRIMARILY THIS HMO/PPO/MGD CARE'
   Q61B03P = 'Q61B_3P. % ADM-PRIMARILY THIS HMO/PPO/MGD CARE'
   Q61A04  = 'Q61A_4. OP NON-METH PRIM PAY: CRIMINAL JUSTICE SYSTEM'
   Q61B04N = 'Q61B_4N. # ADM-PRIMARILY CRIMINAL JUSTICE SYSTEM'
   Q61B04P = 'Q61B_4P. % ADM-PRIMARILY CRIMINAL JUSTICE SYSTEM'
   Q61A05  = 'Q61A_5. OP NON-METH PRIM PAY: MEDICAID'
   Q61B05N = 'Q61B_5N. # ADM-PRIMARILY MEDICAID'
   Q61B05P = 'Q61B_5P. % ADM-PRIMARILY MEDICAID'
   Q61A06  = 'Q61A_6. OP NON-METH PRIM PAY: MEDICARE'
   Q61B06N = 'Q61B_6N. # ADM-PRIMARILY MEDICARE'
   Q61B06P = 'Q61B_6P. % ADM-PRIMARILY MEDICARE'
   Q61A07  = 'Q61A_7. OP NON-METH PRIM PAY: OTHER PUBLIC PAYMENT'
   Q61B07N = 'Q61B_7N. # ADM-PRIMARILY OTHER PUBLIC PAYMENT'
   Q61B07P = 'Q61B_7P. % ADM-PRIMARILY OTHER PUBLIC PAYMENT'
   Q61A08  = 'Q61A_8. OP NON-METH PRIM PAY: NO PAYMENT'
   Q61B08N = 'Q61B_8N. # ADM-PRIMARILY NO PAYMENT'
   Q61B08P = 'Q61B_8P. % ADM-PRIMARILY NO PAYMENT'
   Q61A09  = 'Q61A_9. OP NON-METH PRIM PAY: OTHER/SPECIFY LARGEST TYPE'
   Q61A09S = 'Q61A_9S. OTHER PRIMARY PAYMENT TYPE SPECIFIED'
   Q61B09N = 'Q61B_9N. # ADM-PRIMARILY OTHER/SPECIFY LARGEST TYPE'
   Q61B09P = 'Q61B_9P. % ADM-PRIMARILY OTHER/SPECIFY LARGEST TYPE'
   Q61A10  = 'Q61A_10. OP NON-METH PRIM PAY: UNKNOWN'
   Q61B10N = 'Q61B_10N. # ADM-PRIMARILY UNKNOWN'
   Q61B10P = 'Q61B_10P. % ADM-PRIMARILY UNKNOWN'
   Q61BTN  = 'Q61B_TN.  TOTAL NUMBER OF ADMISSIONS (COPIED FROM Q27)'
   BIG_N   = 'FINAL FRAME SIZE FOR DISCHARGES'
   SMALL_N = 'FINAL SAMPLE SIZE FOR DISCHARGES'
   BIGNT   = 'FINAL FRAME SIZE FOR ITMC'
   SMALLNT = 'FINAL SAMPLE SIZE FOR ITMC'
   PSUTYPE2= 'CENSUS CLASSIFICATION FOR PSUs'
   COMPWT62= 'PSU WEIGHT'
   CENREG  = 'CENSUS REGION'
   PH1FW0  = 'PHASE I FACILITY FINAL WEIGHT'
   PAIR90  = 'PSU STRATUM'
   PH2CFW  = 'PHASE II FACILITY WEIGHT, CONDITIONAL'
   F2BWA0  = 'PHASE II FACILITY BASE WEIGHT'
   VST_PSU = 'PHASE II VARIANCE STRATA'
   VUN_PSU = 'PHASE II VARIANCE UNIT'
   CTCLIENT= 'CATEGORIZED P1 CLIENTS (B1J2)'
   FACTYPE = 'PHASE II: FACILITY TREATMENT TYPE'
   TRIMFAC0= 'PHASE II FACILITY TRIMMING FACTOR'
   CTRLCAT2= 'PHASE II TREATMENT/PSU TYPE FOR RAKING'
   FTOTCNT = 'PHASE I ESTIMATED NUMBER OF FACILITIES'
   FSMPCNT = 'PHASE I NUMBER OF RESPONDING FACILITIES'
   PSF     = 'PHASE II FACILITY RAKING FACTOR'
   F2FWA1  = 'FACILITY FINAL REPLICATE WT 1'
   F2FWA2  = 'FACILITY FINAL REPLICATE WT 2'
   F2FWA3  = 'FACILITY FINAL REPLICATE WT 3'
   F2FWA4  = 'FACILITY FINAL REPLICATE WT 4'
   F2FWA5  = 'FACILITY FINAL REPLICATE WT 5'
   F2FWA6  = 'FACILITY FINAL REPLICATE WT 6'
   F2FWA7  = 'FACILITY FINAL REPLICATE WT 7'
   F2FWA8  = 'FACILITY FINAL REPLICATE WT 8'
   F2FWA9  = 'FACILITY FINAL REPLICATE WT 9'
   F2FWA10 = 'FACILITY FINAL REPLICATE WT 10'
   F2FWA11 = 'FACILITY FINAL REPLICATE WT 11'
   F2FWA12 = 'FACILITY FINAL REPLICATE WT 12'
   F2FWA13 = 'FACILITY FINAL REPLICATE WT 13'
   F2FWA14 = 'FACILITY FINAL REPLICATE WT 14'
   F2FWA15 = 'FACILITY FINAL REPLICATE WT 15'
   F2FWA16 = 'FACILITY FINAL REPLICATE WT 16'
   F2FWA17 = 'FACILITY FINAL REPLICATE WT 17'
   F2FWA18 = 'FACILITY FINAL REPLICATE WT 18'
   F2FWA19 = 'FACILITY FINAL REPLICATE WT 19'
   F2FWA20 = 'FACILITY FINAL REPLICATE WT 20'
   F2FWA21 = 'FACILITY FINAL REPLICATE WT 21'
   F2FWA22 = 'FACILITY FINAL REPLICATE WT 22'
   F2FWA23 = 'FACILITY FINAL REPLICATE WT 23'
   F2FWA24 = 'FACILITY FINAL REPLICATE WT 24'
   F2FWA25 = 'FACILITY FINAL REPLICATE WT 25'
   F2FWA26 = 'FACILITY FINAL REPLICATE WT 26'
   F2FWA27 = 'FACILITY FINAL REPLICATE WT 27'
   F2FWA28 = 'FACILITY FINAL REPLICATE WT 28'
   F2FWA29 = 'FACILITY FINAL REPLICATE WT 29'
   F2FWA30 = 'FACILITY FINAL REPLICATE WT 30'
   F2FWA31 = 'FACILITY FINAL REPLICATE WT 31'
   F2FWA32 = 'FACILITY FINAL REPLICATE WT 32'
   F2FWA33 = 'FACILITY FINAL REPLICATE WT 33'
   F2FWA34 = 'FACILITY FINAL REPLICATE WT 34'
   F2FWA35 = 'FACILITY FINAL REPLICATE WT 35'
   F2FWA36 = 'FACILITY FINAL REPLICATE WT 36'
   F2FWA37 = 'FACILITY FINAL REPLICATE WT 37'
   F2FWA38 = 'FACILITY FINAL REPLICATE WT 38'
   F2FWA39 = 'FACILITY FINAL REPLICATE WT 39'
   F2FWA40 = 'FACILITY FINAL REPLICATE WT 40'
   F2FWA41 = 'FACILITY FINAL REPLICATE WT 41'
   F2FWA42 = 'FACILITY FINAL REPLICATE WT 42'
   F2FWA43 = 'FACILITY FINAL REPLICATE WT 43'
   F2FWA44 = 'FACILITY FINAL REPLICATE WT 44'
   F2FWA45 = 'FACILITY FINAL REPLICATE WT 45'
   F2FWA46 = 'FACILITY FINAL REPLICATE WT 46'
   F2FWA47 = 'FACILITY FINAL REPLICATE WT 47'
   F2FWA48 = 'FACILITY FINAL REPLICATE WT 48'
   F2FWA49 = 'FACILITY FINAL REPLICATE WT 49'
   F2FWA50 = 'FACILITY FINAL REPLICATE WT 50'
   F2FWA51 = 'FACILITY FINAL REPLICATE WT 51'
   F2FWA52 = 'FACILITY FINAL REPLICATE WT 52'
   F2FWA53 = 'FACILITY FINAL REPLICATE WT 53'
   F2FWA54 = 'FACILITY FINAL REPLICATE WT 54'
   F2FWA55 = 'FACILITY FINAL REPLICATE WT 55'
   F2FWA56 = 'FACILITY FINAL REPLICATE WT 56'
   F2FWA57 = 'FACILITY FINAL REPLICATE WT 57'
   F2FWA58 = 'FACILITY FINAL REPLICATE WT 58'
   F2FWA59 = 'FACILITY FINAL REPLICATE WT 59'
   F2FWA60 = 'FACILITY FINAL REPLICATE WT 60'
   F2FWA61 = 'FACILITY FINAL REPLICATE WT 61'
   F2FWA62 = 'FACILITY FINAL REPLICATE WT 62'
   F2FWA63 = 'FACILITY FINAL REPLICATE WT 63'
   F2FWA64 = 'FACILITY FINAL REPLICATE WT 64'
   F2FWA65 = 'FACILITY FINAL REPLICATE WT 65'
   F2FWA66 = 'FACILITY FINAL REPLICATE WT 66'
   F2FWA67 = 'FACILITY FINAL REPLICATE WT 67'
   F2FWA68 = 'FACILITY FINAL REPLICATE WT 68'
   F2FWA69 = 'FACILITY FINAL REPLICATE WT 69'
   F2FWA70 = 'FACILITY FINAL REPLICATE WT 70'
   F2FWA71 = 'FACILITY FINAL REPLICATE WT 71'
   F2FWA72 = 'FACILITY FINAL REPLICATE WT 72'
   F2FWA73 = 'FACILITY FINAL REPLICATE WT 73'
   F2FWA74 = 'FACILITY FINAL REPLICATE WT 74'
   F2FWA75 = 'FACILITY FINAL REPLICATE WT 75'
   F2FWA76 = 'FACILITY FINAL REPLICATE WT 76'
   F2FWA77 = 'FACILITY FINAL REPLICATE WT 77'
   F2FWA78 = 'FACILITY FINAL REPLICATE WT 78'
   F2FWA0  = 'PHASE II FACILITY FINAL WEIGHT'
   TFACRAKE= 'PHASE II FACILITY TRIM FCTR AFTER RAKING'
   QFSTRAT = 'TREATMENT TYPE STRATUM INDICATOR'
   STUDYIND= 'STUDY INDICATOR'
   FIELDPSU= 'PSU NUMBER'
   OWN     = 'TYPE OF OWNERSHIP'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (Q1 <= -6) THEN Q1 = .;
   IF (Q2A <= -6) THEN Q2A = .;
   IF (Q2B <= -6) THEN Q2B = .;
   IF (Q2C <= -6) THEN Q2C = .;
   IF (Q2D <= -6) THEN Q2D = .;
   IF (Q3A <= -6) THEN Q3A = .;
   IF (Q3B <= -6) THEN Q3B = .;
   IF (Q3C <= -6) THEN Q3C = .;
   IF (Q3D <= -6) THEN Q3D = .;
   IF (Q3TOT <= -6) THEN Q3TOT = .;
   IF (Q4A <= -6) THEN Q4A = .;
   IF (Q4B <= -6) THEN Q4B = .;
   IF (Q4C <= -6) THEN Q4C = .;
   IF (Q4D <= -6) THEN Q4D = .;
   IF (Q4E <= -6) THEN Q4E = .;
   IF (Q4F <= -6) THEN Q4F = .;
   IF (Q4G <= -6) THEN Q4G = .;
   IF (Q4H <= -6) THEN Q4H = .;
   IF (Q4I <= -6) THEN Q4I = .;
   IF (Q4J <= -6) THEN Q4J = .;
   IF (Q4K <= -6) THEN Q4K = .;
   IF (BOXA <= -6) THEN BOXA = .;
   IF (BOXB <= -6) THEN BOXB = .;
   IF (BOXC <= -6) THEN BOXC = .;
   IF (BOXD <= -6) THEN BOXD = .;
   IF (Q5A <= -6) THEN Q5A = .;
   IF (Q5B <= -6) THEN Q5B = .;
   IF (Q5C <= -6) THEN Q5C = .;
   IF (Q6A <= -6) THEN Q6A = .;
   IF (Q6B <= -6) THEN Q6B = .;
   IF (Q6C <= -6) THEN Q6C = .;
   IF (Q7A <= -6) THEN Q7A = .;
   IF (Q7AU <= -6) THEN Q7AU = .;
   IF (Q7B <= -6.0) THEN Q7B = .;
   IF (Q7BU <= -6) THEN Q7BU = .;
   IF (Q7C <= -6) THEN Q7C = .;
   IF (Q7CU <= -6) THEN Q7CU = .;
   IF (Q8FMM <= -6) THEN Q8FMM = .;
   IF (Q8FDD <= -6) THEN Q8FDD = .;
   IF (Q8FYY <= -6) THEN Q8FYY = .;
   IF (Q8TMM <= -6) THEN Q8TMM = .;
   IF (Q8TDD <= -6) THEN Q8TDD = .;
   IF (Q8TYY <= -6) THEN Q8TYY = .;
   IF (Q9A <= -6) THEN Q9A = .;
   IF (Q9B <= -6) THEN Q9B = .;
   IF (Q9C <= -6) THEN Q9C = .;
   IF (Q9D <= -6) THEN Q9D = .;
   IF (Q10A <= -6) THEN Q10A = .;
   IF (Q11A <= -6) THEN Q11A = .;
   IF (Q10B <= -6) THEN Q10B = .;
   IF (Q11B <= -6) THEN Q11B = .;
   IF (Q10C <= -6) THEN Q10C = .;
   IF (Q11C <= -6) THEN Q11C = .;
   IF (Q10D <= -6) THEN Q10D = .;
   IF (Q11D <= -6) THEN Q11D = .;
   IF (Q10E <= -6) THEN Q10E = .;
   IF (Q10ES <= -6) THEN Q10ES = .;
   IF (Q11E <= -1) THEN Q11E = .;
   IF (Q12A <= -6) THEN Q12A = .;
   IF (Q12B <= -6) THEN Q12B = .;
   IF (Q12C <= -6) THEN Q12C = .;
   IF (Q13A <= -6) THEN Q13A = .;
   IF (Q13B <= -6) THEN Q13B = .;
   IF (Q13C <= -6) THEN Q13C = .;
   IF (Q14 <= -6) THEN Q14 = .;
   IF (Q15A <= -6) THEN Q15A = .;
   IF (Q15AU <= -6) THEN Q15AU = .;
   IF (Q15B <= -6) THEN Q15B = .;
   IF (Q15BU <= -6) THEN Q15BU = .;
   IF (Q15C <= -6) THEN Q15C = .;
   IF (Q15CU <= -6) THEN Q15CU = .;
   IF (Q16FMM <= -6) THEN Q16FMM = .;
   IF (Q16FDD <= -6) THEN Q16FDD = .;
   IF (Q16FYY <= -6) THEN Q16FYY = .;
   IF (Q16TMM <= -6) THEN Q16TMM = .;
   IF (Q16TDD <= -6) THEN Q16TDD = .;
   IF (Q16TYY <= -6) THEN Q16TYY = .;
   IF (Q17A <= -6) THEN Q17A = .;
   IF (Q17B <= -6) THEN Q17B = .;
   IF (Q17C <= -6.0) THEN Q17C = .;
   IF (Q17D <= -6.0) THEN Q17D = .;
   IF (Q18A <= -6) THEN Q18A = .;
   IF (Q19A <= -6) THEN Q19A = .;
   IF (Q18B <= -6) THEN Q18B = .;
   IF (Q19B <= -6.0) THEN Q19B = .;
   IF (Q18C <= -6) THEN Q18C = .;
   IF (Q19C <= -6) THEN Q19C = .;
   IF (Q18D <= -6) THEN Q18D = .;
   IF (Q19D <= -6) THEN Q19D = .;
   IF (Q18E <= -6) THEN Q18E = .;
   IF (Q18ES <= -6) THEN Q18ES = .;
   IF (Q19E <= -6.0) THEN Q19E = .;
   IF (Q20 <= -6) THEN Q20 = .;
   IF (Q21 <= -1.0) THEN Q21 = .;
   IF (Q21U <= -6) THEN Q21U = .;
   IF (Q22FMM <= -6) THEN Q22FMM = .;
   IF (Q22FDD <= -6) THEN Q22FDD = .;
   IF (Q22FYY <= -6) THEN Q22FYY = .;
   IF (Q22TMM <= -6) THEN Q22TMM = .;
   IF (Q22TDD <= -6) THEN Q22TDD = .;
   IF (Q22TYY <= -6) THEN Q22TYY = .;
   IF (Q23A <= -6.00) THEN Q23A = .;
   IF (Q23B <= -6.00) THEN Q23B = .;
   IF (Q24A <= -6) THEN Q24A = .;
   IF (Q25A <= -6.0) THEN Q25A = .;
   IF (Q24B <= -6) THEN Q24B = .;
   IF (Q25B <= -6.0) THEN Q25B = .;
   IF (Q24C <= -6) THEN Q24C = .;
   IF (Q25C <= -6.0) THEN Q25C = .;
   IF (Q24D <= -6) THEN Q24D = .;
   IF (Q25D <= -6.0) THEN Q25D = .;
   IF (Q24E <= -6) THEN Q24E = .;
   IF (Q24ES <= -6) THEN Q24ES = .;
   IF (Q25E <= -6.00) THEN Q25E = .;
   IF (Q26 <= -6.0) THEN Q26 = .;
   IF (Q27 <= -6) THEN Q27 = .;
   IF (Q28 <= -1.00) THEN Q28 = .;
   IF (Q28U <= -6) THEN Q28U = .;
   IF (Q29 <= -6) THEN Q29 = .;
   IF (Q30 <= -6) THEN Q30 = .;
   IF (Q31 <= -6) THEN Q31 = .;
   IF (Q31U <= -6) THEN Q31U = .;
   IF (Q32FMM <= -6) THEN Q32FMM = .;
   IF (Q32FDD <= -6) THEN Q32FDD = .;
   IF (Q32FYY <= -6) THEN Q32FYY = .;
   IF (Q32TMM <= -6) THEN Q32TMM = .;
   IF (Q32TDD <= -6) THEN Q32TDD = .;
   IF (Q32TYY <= -6) THEN Q32TYY = .;
   IF (Q33A <= -1.00) THEN Q33A = .;
   IF (Q33B <= -1.00) THEN Q33B = .;
   IF (Q34A <= -6) THEN Q34A = .;
   IF (Q35A <= -6.0) THEN Q35A = .;
   IF (Q34B <= -6) THEN Q34B = .;
   IF (Q35B <= -6.0) THEN Q35B = .;
   IF (Q34C <= -6) THEN Q34C = .;
   IF (Q35C <= -6.0) THEN Q35C = .;
   IF (Q34D <= -6) THEN Q34D = .;
   IF (Q35D <= -6) THEN Q35D = .;
   IF (Q34E <= -6) THEN Q34E = .;
   IF (Q34ES <= -6) THEN Q34ES = .;
   IF (Q35E <= -6.00) THEN Q35E = .;
   IF (Q36 <= -6) THEN Q36 = .;
   IF (Q37 <= -6.0) THEN Q37 = .;
   IF (Q38 <= -6.00) THEN Q38 = .;
   IF (Q39 <= -6.00) THEN Q39 = .;
   IF (Q40A <= -6) THEN Q40A = .;
   IF (Q40B <= -6) THEN Q40B = .;
   IF (Q40C <= -6) THEN Q40C = .;
   IF (Q41 <= -6) THEN Q41 = .;
   IF (Q42A <= -6) THEN Q42A = .;
   IF (Q42B <= -6) THEN Q42B = .;
   IF (Q42C <= -6) THEN Q42C = .;
   IF (Q42D <= -6) THEN Q42D = .;
   IF (Q42E <= -6) THEN Q42E = .;
   IF (Q42F <= -6) THEN Q42F = .;
   IF (Q42G <= -6) THEN Q42G = .;
   IF (Q42H <= -6) THEN Q42H = .;
   IF (Q42I <= -6) THEN Q42I = .;
   IF (Q42J <= -6) THEN Q42J = .;
   IF (Q43 <= -6) THEN Q43 = .;
   IF (Q44 <= -6) THEN Q44 = .;
   IF (Q45 <= -6) THEN Q45 = .;
   IF (Q45B <= -6) THEN Q45B = .;
   IF (Q45C <= -6) THEN Q45C = .;
   IF (Q46 <= -6) THEN Q46 = .;
   IF (Q46OTH1 <= -6) THEN Q46OTH1 = .;
   IF (Q46OTH2 <= -6) THEN Q46OTH2 = .;
   IF (Q46OTH3 <= -6) THEN Q46OTH3 = .;
   IF (Q47BOX <= -6) THEN Q47BOX = .;
   IF (R9A1 <= -6.00) THEN R9A1 = .;
   IF (R9B1 <= -6.0) THEN R9B1 = .;
   IF (R9C1 <= -6.0) THEN R9C1 = .;
   IF (R9D1 <= -6.00) THEN R9D1 = .;
   IF (R9E1 <= -6.00) THEN R9E1 = .;
   IF (R9F1 <= -6.00) THEN R9F1 = .;
   IF (R9G1 <= -6.0) THEN R9G1 = .;
   IF (R9H1 <= -6.00) THEN R9H1 = .;
   IF (R9I1 <= -6.00) THEN R9I1 = .;
   IF (R9A2 <= -6) THEN R9A2 = .;
   IF (R9B2 <= -6) THEN R9B2 = .;
   IF (R9C2 <= -6) THEN R9C2 = .;
   IF (R9D2 <= -6) THEN R9D2 = .;
   IF (R9E2 <= -6.0) THEN R9E2 = .;
   IF (R9F2 <= -6) THEN R9F2 = .;
   IF (R9G2 <= -6) THEN R9G2 = .;
   IF (R9H2 <= -6) THEN R9H2 = .;
   IF (R9I2 <= -6.0) THEN R9I2 = .;
   IF (R9A3 <= -6) THEN R9A3 = .;
   IF (R9B3 <= -6) THEN R9B3 = .;
   IF (R9C3 <= -6) THEN R9C3 = .;
   IF (R9D3 <= -6) THEN R9D3 = .;
   IF (R9E3 <= -6) THEN R9E3 = .;
   IF (R9F3 <= -6) THEN R9F3 = .;
   IF (R9G3 <= -6) THEN R9G3 = .;
   IF (R9H3 <= -6.0) THEN R9H3 = .;
   IF (R9I3 <= -6.0) THEN R9I3 = .;
   IF (Q47AW <= -6.00) THEN Q47AW = .;
   IF (Q47BW <= -6.00) THEN Q47BW = .;
   IF (Q47CW <= -6.0) THEN Q47CW = .;
   IF (Q47DW <= -6.0) THEN Q47DW = .;
   IF (Q47EW <= -6.00) THEN Q47EW = .;
   IF (Q47FW <= -6.0) THEN Q47FW = .;
   IF (Q47GW <= -6.0) THEN Q47GW = .;
   IF (Q47HW <= -6.0) THEN Q47HW = .;
   IF (Q47IW <= -6.00) THEN Q47IW = .;
   IF (BOXE <= -6) THEN BOXE = .;
   IF (Q48A <= -6) THEN Q48A = .;
   IF (Q48B <= -6) THEN Q48B = .;
   IF (Q48C <= -6) THEN Q48C = .;
   IF (Q48D <= -6) THEN Q48D = .;
   IF (Q48E <= -6) THEN Q48E = .;
   IF (Q49A <= -1.00) THEN Q49A = .;
   IF (Q49AU <= -6) THEN Q49AU = .;
   IF (Q50A <= -6) THEN Q50A = .;
   IF (Q49B <= -1.00) THEN Q49B = .;
   IF (Q49BU <= -6.00) THEN Q49BU = .;
   IF (Q50B <= -6.00) THEN Q50B = .;
   IF (Q49C <= -1.00) THEN Q49C = .;
   IF (Q49CU <= -6.00) THEN Q49CU = .;
   IF (Q50C <= -6.00) THEN Q50C = .;
   IF (Q49D <= -1.00) THEN Q49D = .;
   IF (Q49DU <= -6.00) THEN Q49DU = .;
   IF (Q50D <= -6.00) THEN Q50D = .;
   IF (Q49E <= -1.00) THEN Q49E = .;
   IF (Q49EU <= -6.00) THEN Q49EU = .;
   IF (Q50E <= -6.00) THEN Q50E = .;
   IF (Q49F <= -1.00) THEN Q49F = .;
   IF (Q49FU <= -6.00) THEN Q49FU = .;
   IF (Q50F <= -6.00) THEN Q50F = .;
   IF (Q49G <= -1.00) THEN Q49G = .;
   IF (Q49GU <= -6.00) THEN Q49GU = .;
   IF (Q50G <= -6.00) THEN Q50G = .;
   IF (Q49H <= -1.00) THEN Q49H = .;
   IF (Q49HU <= -6) THEN Q49HU = .;
   IF (Q50H <= -6) THEN Q50H = .;
   IF (Q51A <= -6) THEN Q51A = .;
   IF (Q51APC <= -6) THEN Q51APC = .;
   IF (Q51B <= -6) THEN Q51B = .;
   IF (Q51BPC <= -6) THEN Q51BPC = .;
   IF (Q51C <= -6) THEN Q51C = .;
   IF (Q51CPC <= -6.0) THEN Q51CPC = .;
   IF (Q51D <= -6) THEN Q51D = .;
   IF (Q51DPC <= -6) THEN Q51DPC = .;
   IF (Q51E <= -6) THEN Q51E = .;
   IF (Q51EPC <= -6.00) THEN Q51EPC = .;
   IF (Q51F <= -6) THEN Q51F = .;
   IF (Q51FPC <= -6.00) THEN Q51FPC = .;
   IF (Q51G <= -6) THEN Q51G = .;
   IF (Q51GPC <= -6.00) THEN Q51GPC = .;
   IF (Q51H <= -6) THEN Q51H = .;
   IF (Q51HPC <= -6.00) THEN Q51HPC = .;
   IF (Q51I <= -6) THEN Q51I = .;
   IF (Q51IPC <= -6.0) THEN Q51IPC = .;
   IF (Q51J <= -6) THEN Q51J = .;
   IF (Q51JPC <= -6) THEN Q51JPC = .;
   IF (Q51K <= -6) THEN Q51K = .;
   IF (Q51KPC <= -6.0) THEN Q51KPC = .;
   IF (Q51L <= -6) THEN Q51L = .;
   IF (Q51LPC <= -6.0) THEN Q51LPC = .;
   IF (Q51M <= -6) THEN Q51M = .;
   IF (Q51MPC <= -6.0) THEN Q51MPC = .;
   IF (Q51N <= -6) THEN Q51N = .;
   IF (Q51NPC <= -6.0) THEN Q51NPC = .;
   IF (Q51O <= -6) THEN Q51O = .;
   IF (Q51OPC <= -6.0) THEN Q51OPC = .;
   IF (Q51P <= -6) THEN Q51P = .;
   IF (Q51PPC <= -6) THEN Q51PPC = .;
   IF (Q51Q <= -6) THEN Q51Q = .;
   IF (Q51QPC <= -6.0) THEN Q51QPC = .;
   IF (Q51R <= -6) THEN Q51R = .;
   IF (Q51RPC <= -6) THEN Q51RPC = .;
   IF (Q52 <= -1) THEN Q52 = .;
   IF (Q53FMM <= -6) THEN Q53FMM = .;
   IF (Q53FDD <= -6) THEN Q53FDD = .;
   IF (Q53FYY <= -6) THEN Q53FYY = .;
   IF (Q53TMM <= -6) THEN Q53TMM = .;
   IF (Q53TDD <= -6) THEN Q53TDD = .;
   IF (Q53TYY <= -6) THEN Q53TYY = .;
   IF (Q54BOX <= -6) THEN Q54BOX = .;
   IF (Q54PC <= -6) THEN Q54PC = .;
   IF (Q55 <= -1) THEN Q55 = .;
   IF (Q56BOX <= -6) THEN Q56BOX = .;
   IF (Q56PC <= -6) THEN Q56PC = .;
   IF (TMEH <= -6) THEN TMEH = .;
   IF (TMEM <= -6) THEN TMEM = .;
   IF (TMEAP <= -6) THEN TMEAP = .;
   IF (Q57FMM <= -6) THEN Q57FMM = .;
   IF (Q57FDD <= -6) THEN Q57FDD = .;
   IF (Q57FYY <= -6) THEN Q57FYY = .;
   IF (Q57TMM <= -6) THEN Q57TMM = .;
   IF (Q57TDD <= -6) THEN Q57TDD = .;
   IF (Q57TYY <= -6) THEN Q57TYY = .;
   IF (Q57A01 <= -6) THEN Q57A01 = .;
   IF (Q57B01N <= -6) THEN Q57B01N = .;
   IF (Q57B01P <= -6) THEN Q57B01P = .;
   IF (Q57A02 <= -6) THEN Q57A02 = .;
   IF (Q57B02N <= -6) THEN Q57B02N = .;
   IF (Q57B02P <= -6) THEN Q57B02P = .;
   IF (Q57A03 <= -6) THEN Q57A03 = .;
   IF (Q57B03N <= -6) THEN Q57B03N = .;
   IF (Q57B03P <= -6) THEN Q57B03P = .;
   IF (Q57A04 <= -6) THEN Q57A04 = .;
   IF (Q57B04N <= -6) THEN Q57B04N = .;
   IF (Q57B04P <= -6) THEN Q57B04P = .;
   IF (Q57A05 <= -6) THEN Q57A05 = .;
   IF (Q57B05N <= -6) THEN Q57B05N = .;
   IF (Q57B05P <= -6) THEN Q57B05P = .;
   IF (Q57A06 <= -6) THEN Q57A06 = .;
   IF (Q57B06N <= -6) THEN Q57B06N = .;
   IF (Q57B06P <= -6) THEN Q57B06P = .;
   IF (Q57A07 <= -6) THEN Q57A07 = .;
   IF (Q57B07N <= -6) THEN Q57B07N = .;
   IF (Q57B07P <= -6) THEN Q57B07P = .;
   IF (Q57A08 <= -6) THEN Q57A08 = .;
   IF (Q57B08N <= -6) THEN Q57B08N = .;
   IF (Q57B08P <= -6) THEN Q57B08P = .;
   IF (Q57A09 <= -6) THEN Q57A09 = .;
   IF (Q57A09S <= -6) THEN Q57A09S = .;
   IF (Q57B09N <= -6) THEN Q57B09N = .;
   IF (Q57B09P <= -6) THEN Q57B09P = .;
   IF (Q57A10 <= -6) THEN Q57A10 = .;
   IF (Q57B10N <= -6) THEN Q57B10N = .;
   IF (Q57B10P <= -6) THEN Q57B10P = .;
   IF (Q57BTN <= -6) THEN Q57BTN = .;
   IF (Q58FMM <= -6) THEN Q58FMM = .;
   IF (Q58FDD <= -6) THEN Q58FDD = .;
   IF (Q58FYY <= -6) THEN Q58FYY = .;
   IF (Q58TMM <= -6) THEN Q58TMM = .;
   IF (Q58TDD <= -6) THEN Q58TDD = .;
   IF (Q58TYY <= -6) THEN Q58TYY = .;
   IF (Q58A01 <= -6) THEN Q58A01 = .;
   IF (Q58B01N <= -6) THEN Q58B01N = .;
   IF (Q58B01P <= -6) THEN Q58B01P = .;
   IF (Q58A02 <= -6) THEN Q58A02 = .;
   IF (Q58B02N <= -6) THEN Q58B02N = .;
   IF (Q58B02P <= -6) THEN Q58B02P = .;
   IF (Q58A03 <= -6) THEN Q58A03 = .;
   IF (Q58B03N <= -6) THEN Q58B03N = .;
   IF (Q58B03P <= -6) THEN Q58B03P = .;
   IF (Q58A04 <= -6) THEN Q58A04 = .;
   IF (Q58B04N <= -6) THEN Q58B04N = .;
   IF (Q58B04P <= -6) THEN Q58B04P = .;
   IF (Q58A05 <= -6) THEN Q58A05 = .;
   IF (Q58B05N <= -6) THEN Q58B05N = .;
   IF (Q58B05P <= -6) THEN Q58B05P = .;
   IF (Q58A06 <= -6) THEN Q58A06 = .;
   IF (Q58B06N <= -6) THEN Q58B06N = .;
   IF (Q58B06P <= -6) THEN Q58B06P = .;
   IF (Q58A07 <= -6) THEN Q58A07 = .;
   IF (Q58B07N <= -6) THEN Q58B07N = .;
   IF (Q58B07P <= -6) THEN Q58B07P = .;
   IF (Q58A08 <= -6) THEN Q58A08 = .;
   IF (Q58B08N <= -6) THEN Q58B08N = .;
   IF (Q58B08P <= -6) THEN Q58B08P = .;
   IF (Q58A09 <= -6) THEN Q58A09 = .;
   IF (Q58A09S <= -6) THEN Q58A09S = .;
   IF (Q58B09N <= -6) THEN Q58B09N = .;
   IF (Q58B09P <= -6) THEN Q58B09P = .;
   IF (Q58A10 <= -6) THEN Q58A10 = .;
   IF (Q58B10N <= -6) THEN Q58B10N = .;
   IF (Q58B10P <= -6) THEN Q58B10P = .;
   IF (Q58BTN <= -6) THEN Q58BTN = .;
   IF (Q59FMM <= -6) THEN Q59FMM = .;
   IF (Q59FDD <= -6) THEN Q59FDD = .;
   IF (Q59FYY <= -6) THEN Q59FYY = .;
   IF (Q59TMM <= -6) THEN Q59TMM = .;
   IF (Q59TDD <= -6) THEN Q59TDD = .;
   IF (Q59TYY <= -6) THEN Q59TYY = .;
   IF (Q59A01 <= -6) THEN Q59A01 = .;
   IF (Q59B01N <= -6) THEN Q59B01N = .;
   IF (Q59B01P <= -6) THEN Q59B01P = .;
   IF (Q59A02 <= -6) THEN Q59A02 = .;
   IF (Q59B02N <= -6) THEN Q59B02N = .;
   IF (Q59B02P <= -6) THEN Q59B02P = .;
   IF (Q59A03 <= -6) THEN Q59A03 = .;
   IF (Q59B03N <= -6) THEN Q59B03N = .;
   IF (Q59B03P <= -6) THEN Q59B03P = .;
   IF (Q59A04 <= -6) THEN Q59A04 = .;
   IF (Q59B04N <= -6) THEN Q59B04N = .;
   IF (Q59B04P <= -6) THEN Q59B04P = .;
   IF (Q59A05 <= -6) THEN Q59A05 = .;
   IF (Q59B05N <= -6) THEN Q59B05N = .;
   IF (Q59B05P <= -6) THEN Q59B05P = .;
   IF (Q59A06 <= -6) THEN Q59A06 = .;
   IF (Q59B06N <= -6) THEN Q59B06N = .;
   IF (Q59B06P <= -6) THEN Q59B06P = .;
   IF (Q59A07 <= -6) THEN Q59A07 = .;
   IF (Q59B07N <= -6) THEN Q59B07N = .;
   IF (Q59B07P <= -6) THEN Q59B07P = .;
   IF (Q59A08 <= -6) THEN Q59A08 = .;
   IF (Q59B08N <= -6) THEN Q59B08N = .;
   IF (Q59B08P <= -6) THEN Q59B08P = .;
   IF (Q59A09 <= -6) THEN Q59A09 = .;
   IF (Q59A09S <= -6) THEN Q59A09S = .;
   IF (Q59B09N <= -6) THEN Q59B09N = .;
   IF (Q59B09P <= -6) THEN Q59B09P = .;
   IF (Q59A10 <= -6) THEN Q59A10 = .;
   IF (Q59B10N <= -6) THEN Q59B10N = .;
   IF (Q59B10P <= -6) THEN Q59B10P = .;
   IF (Q59BTN <= -6) THEN Q59BTN = .;
   IF (Q60 <= -6) THEN Q60 = .;
   IF (Q61FMM <= -6) THEN Q61FMM = .;
   IF (Q61FDD <= -6) THEN Q61FDD = .;
   IF (Q61FYY <= -6) THEN Q61FYY = .;
   IF (Q61TMM <= -6) THEN Q61TMM = .;
   IF (Q61TDD <= -6) THEN Q61TDD = .;
   IF (Q61TYY <= -6) THEN Q61TYY = .;
   IF (Q61A01 <= -6) THEN Q61A01 = .;
   IF (Q61B01N <= -6) THEN Q61B01N = .;
   IF (Q61B01P <= -6) THEN Q61B01P = .;
   IF (Q61A02 <= -6) THEN Q61A02 = .;
   IF (Q61B02N <= -6) THEN Q61B02N = .;
   IF (Q61B02P <= -6) THEN Q61B02P = .;
   IF (Q61A03 <= -6) THEN Q61A03 = .;
   IF (Q61B03N <= -6) THEN Q61B03N = .;
   IF (Q61B03P <= -6) THEN Q61B03P = .;
   IF (Q61A04 <= -6) THEN Q61A04 = .;
   IF (Q61B04N <= -6) THEN Q61B04N = .;
   IF (Q61B04P <= -6) THEN Q61B04P = .;
   IF (Q61A05 <= -6) THEN Q61A05 = .;
   IF (Q61B05N <= -6) THEN Q61B05N = .;
   IF (Q61B05P <= -6) THEN Q61B05P = .;
   IF (Q61A06 <= -6) THEN Q61A06 = .;
   IF (Q61B06N <= -6) THEN Q61B06N = .;
   IF (Q61B06P <= -6) THEN Q61B06P = .;
   IF (Q61A07 <= -6) THEN Q61A07 = .;
   IF (Q61B07N <= -6) THEN Q61B07N = .;
   IF (Q61B07P <= -6) THEN Q61B07P = .;
   IF (Q61A08 <= -6) THEN Q61A08 = .;
   IF (Q61B08N <= -6) THEN Q61B08N = .;
   IF (Q61B08P <= -6) THEN Q61B08P = .;
   IF (Q61A09 <= -6) THEN Q61A09 = .;
   IF (Q61A09S <= -6) THEN Q61A09S = .;
   IF (Q61B09N <= -6) THEN Q61B09N = .;
   IF (Q61B09P <= -6) THEN Q61B09P = .;
   IF (Q61A10 <= -6) THEN Q61A10 = .;
   IF (Q61B10N <= -6) THEN Q61B10N = .;
   IF (Q61B10P <= -6) THEN Q61B10P = .;
   IF (Q61BTN <= -6) THEN Q61BTN = .;
   IF (BIG_N <= -6) THEN BIG_N = .;
   IF (SMALL_N <= -6) THEN SMALL_N = .;
   IF (BIGNT <= -6) THEN BIGNT = .;
   IF (SMALLNT <= -6) THEN SMALLNT = .;
   IF (PSUTYPE2 <= -6) THEN PSUTYPE2 = .;
   IF (COMPWT62 <= -6.0000) THEN COMPWT62 = .;
   IF (CENREG <= -6) THEN CENREG = .;
   IF (PH1FW0 <= -6.0000) THEN PH1FW0 = .;
   IF (PH2CFW <= -6.0000) THEN PH2CFW = .;
   IF (F2BWA0 <= -6.0000) THEN F2BWA0 = .;
   IF (VST_PSU <= -6) THEN VST_PSU = .;
   IF (VUN_PSU <= -6) THEN VUN_PSU = .;
   IF (CTCLIENT <= -6) THEN CTCLIENT = .;
   IF (FACTYPE <= -6) THEN FACTYPE = .;
   IF (TRIMFAC0 <= -6.0000) THEN TRIMFAC0 = .;
   IF (CTRLCAT2 <= -6) THEN CTRLCAT2 = .;
   IF (FTOTCNT <= -6) THEN FTOTCNT = .;
   IF (FSMPCNT <= -6) THEN FSMPCNT = .;
   IF (PSF <= -6.0000) THEN PSF = .;
   IF (F2FWA1 <= -6.0000) THEN F2FWA1 = .;
   IF (F2FWA2 <= -6.0000) THEN F2FWA2 = .;
   IF (F2FWA3 <= -6.0000) THEN F2FWA3 = .;
   IF (F2FWA4 <= -6.0000) THEN F2FWA4 = .;
   IF (F2FWA5 <= -6.0000) THEN F2FWA5 = .;
   IF (F2FWA6 <= -6.0000) THEN F2FWA6 = .;
   IF (F2FWA7 <= -6.0000) THEN F2FWA7 = .;
   IF (F2FWA8 <= -6.0000) THEN F2FWA8 = .;
   IF (F2FWA9 <= -6.0000) THEN F2FWA9 = .;
   IF (F2FWA10 <= -6.0000) THEN F2FWA10 = .;
   IF (F2FWA11 <= -6.0000) THEN F2FWA11 = .;
   IF (F2FWA12 <= -6.0000) THEN F2FWA12 = .;
   IF (F2FWA13 <= -6.0000) THEN F2FWA13 = .;
   IF (F2FWA14 <= -6.0000) THEN F2FWA14 = .;
   IF (F2FWA15 <= -6.0000) THEN F2FWA15 = .;
   IF (F2FWA16 <= -6.0000) THEN F2FWA16 = .;
   IF (F2FWA17 <= -6.0000) THEN F2FWA17 = .;
   IF (F2FWA18 <= -6.0000) THEN F2FWA18 = .;
   IF (F2FWA19 <= -6.0000) THEN F2FWA19 = .;
   IF (F2FWA20 <= -6.0000) THEN F2FWA20 = .;
   IF (F2FWA21 <= -6.0000) THEN F2FWA21 = .;
   IF (F2FWA22 <= -6.0000) THEN F2FWA22 = .;
   IF (F2FWA23 <= -6.0000) THEN F2FWA23 = .;
   IF (F2FWA24 <= -6.0000) THEN F2FWA24 = .;
   IF (F2FWA25 <= -6.0000) THEN F2FWA25 = .;
   IF (F2FWA26 <= -6.0000) THEN F2FWA26 = .;
   IF (F2FWA27 <= -6.0000) THEN F2FWA27 = .;
   IF (F2FWA28 <= -6.0000) THEN F2FWA28 = .;
   IF (F2FWA29 <= -6.0000) THEN F2FWA29 = .;
   IF (F2FWA30 <= -6.0000) THEN F2FWA30 = .;
   IF (F2FWA31 <= -6.0000) THEN F2FWA31 = .;
   IF (F2FWA32 <= -6.0000) THEN F2FWA32 = .;
   IF (F2FWA33 <= -6.0000) THEN F2FWA33 = .;
   IF (F2FWA34 <= -6.0000) THEN F2FWA34 = .;
   IF (F2FWA35 <= -6.0000) THEN F2FWA35 = .;
   IF (F2FWA36 <= -6.0000) THEN F2FWA36 = .;
   IF (F2FWA37 <= -6.0000) THEN F2FWA37 = .;
   IF (F2FWA38 <= -6.0000) THEN F2FWA38 = .;
   IF (F2FWA39 <= -6.0000) THEN F2FWA39 = .;
   IF (F2FWA40 <= -6.0000) THEN F2FWA40 = .;
   IF (F2FWA41 <= -6.0000) THEN F2FWA41 = .;
   IF (F2FWA42 <= -6.0000) THEN F2FWA42 = .;
   IF (F2FWA43 <= -6.0000) THEN F2FWA43 = .;
   IF (F2FWA44 <= -6.0000) THEN F2FWA44 = .;
   IF (F2FWA45 <= -6.0000) THEN F2FWA45 = .;
   IF (F2FWA46 <= -6.0000) THEN F2FWA46 = .;
   IF (F2FWA47 <= -6.0000) THEN F2FWA47 = .;
   IF (F2FWA48 <= -6.0000) THEN F2FWA48 = .;
   IF (F2FWA49 <= -6.0000) THEN F2FWA49 = .;
   IF (F2FWA50 <= -6.0000) THEN F2FWA50 = .;
   IF (F2FWA51 <= -6.0000) THEN F2FWA51 = .;
   IF (F2FWA52 <= -6.0000) THEN F2FWA52 = .;
   IF (F2FWA53 <= -6.0000) THEN F2FWA53 = .;
   IF (F2FWA54 <= -6.0000) THEN F2FWA54 = .;
   IF (F2FWA55 <= -6.0000) THEN F2FWA55 = .;
   IF (F2FWA56 <= -6.0000) THEN F2FWA56 = .;
   IF (F2FWA57 <= -6.0000) THEN F2FWA57 = .;
   IF (F2FWA58 <= -6.0000) THEN F2FWA58 = .;
   IF (F2FWA59 <= -6.0000) THEN F2FWA59 = .;
   IF (F2FWA60 <= -6.0000) THEN F2FWA60 = .;
   IF (F2FWA61 <= -6.0000) THEN F2FWA61 = .;
   IF (F2FWA62 <= -6.0000) THEN F2FWA62 = .;
   IF (F2FWA63 <= -6.0000) THEN F2FWA63 = .;
   IF (F2FWA64 <= -6.0000) THEN F2FWA64 = .;
   IF (F2FWA65 <= -6.0000) THEN F2FWA65 = .;
   IF (F2FWA66 <= -6.0000) THEN F2FWA66 = .;
   IF (F2FWA67 <= -6.0000) THEN F2FWA67 = .;
   IF (F2FWA68 <= -6.0000) THEN F2FWA68 = .;
   IF (F2FWA69 <= -6.0000) THEN F2FWA69 = .;
   IF (F2FWA70 <= -6.0000) THEN F2FWA70 = .;
   IF (F2FWA71 <= -6.0000) THEN F2FWA71 = .;
   IF (F2FWA72 <= -6.0000) THEN F2FWA72 = .;
   IF (F2FWA73 <= -6.0000) THEN F2FWA73 = .;
   IF (F2FWA74 <= -6.0000) THEN F2FWA74 = .;
   IF (F2FWA75 <= -6.0000) THEN F2FWA75 = .;
   IF (F2FWA76 <= -6.0000) THEN F2FWA76 = .;
   IF (F2FWA77 <= -6.0000) THEN F2FWA77 = .;
   IF (F2FWA78 <= -6.0000) THEN F2FWA78 = .;
   IF (F2FWA0 <= -6.0000) THEN F2FWA0 = .;
   IF (OWN <= -6) THEN OWN = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT Q1 q1ffffff. Q2A q2a. Q2B q2b.
         Q2C q2c. Q2D q2d. Q3A q3a.
         Q3B q3b. Q3C q3c. Q3D q3d.
         Q3TOT q3tot. Q4A q4a. Q4B q4b.
         Q4C q4c. Q4D q4d. Q4E q4e.
         Q4F q4f. Q4G q4g. Q4H q4h.
         Q4I q4i. Q4J q4j. Q4K q4k.
         BOXA boxa. BOXB boxb. BOXC boxc.
         BOXD boxd. Q5A q5a. Q5B q5b.
         Q5C q5c. Q6A q6a. Q6B q6b.
         Q6C q6c. Q7A q7a. Q7AU q7au.
         Q7B q7b. Q7BU q7bu. Q7C q7c.
         Q7CU q7cu. Q8FMM q8fmm. Q8FDD q8fdd.
         Q8FYY q8fyy. Q8TMM q8tmm. Q8TDD q8tdd.
         Q8TYY q8tyy. Q9A q9a. Q9B q9b.
         Q9C q9c. Q9D q9d. Q10A q10a.
         Q11A q11a. Q10B q10b. Q11B q11b.
         Q10C q10c. Q11C q11c. Q10D q10d.
         Q11D q11d. Q10E q10e. Q10ES q10es.
         Q11E q11e. Q12A q12a. Q12B q12b.
         Q12C q12c. Q13A q13a. Q13B q13b.
         Q13C q13c. Q14 q14fffff. Q15A q15a.
         Q15AU q15au. Q15B q15b. Q15BU q15bu.
         Q15C q15c. Q15CU q15cu. Q16FMM q16fmm.
         Q16FDD q16fdd. Q16FYY q16fyy. Q16TMM q16tmm.
         Q16TDD q16tdd. Q16TYY q16tyy. Q17A q17a.
         Q17B q17b. Q17C q17c. Q17D q17d.
         Q18A q18a. Q19A q19a. Q18B q18b.
         Q19B q19b. Q18C q18c. Q19C q19c.
         Q18D q18d. Q19D q19d. Q18E q18e.
         Q18ES q18es. Q19E q19e. Q20 q20fffff.
         Q21 q21fffff. Q21U q21u. Q22FMM q22fmm.
         Q22FDD q22fdd. Q22FYY q22fyy. Q22TMM q22tmm.
         Q22TDD q22tdd. Q22TYY q22tyy. Q23A q23a.
         Q23B q23b. Q24A q24a. Q25A q25a.
         Q24B q24b. Q25B q25b. Q24C q24c.
         Q25C q25c. Q24D q24d. Q25D q25d.
         Q24E q24e. Q24ES q24es. Q25E q25e.
         Q26 q26fffff. Q27 q27fffff. Q28 q28fffff.
         Q28U q28u. Q29 q29fffff. Q30 q30fffff.
         Q31 q31fffff. Q31U q31u. Q32FMM q32fmm.
         Q32FDD q32fdd. Q32FYY q32fyy. Q32TMM q32tmm.
         Q32TDD q32tdd. Q32TYY q32tyy. Q33A q33a.
         Q33B q33b. Q34A q34a. Q35A q35a.
         Q34B q34b. Q35B q35b. Q34C q34c.
         Q35C q35c. Q34D q34d. Q35D q35d.
         Q34E q34e. Q34ES q34es. Q35E q35e.
         Q36 q36fffff. Q37 q37fffff. Q38 q38fffff.
         Q39 q39fffff. Q40A q40a. Q40B q40b.
         Q40C q40c. Q41 q41fffff. Q42A q42a.
         Q42B q42b. Q42C q42c. Q42D q42d.
         Q42E q42e. Q42F q42f. Q42G q42g.
         Q42H q42h. Q42I q42i. Q42J q42j.
         Q43 q43fffff. Q44 q44fffff. Q45 q45fffff.
         Q45B q45b. Q45C q45c. Q46 q46fffff.
         Q46OTH1 q46oth1f. Q46OTH2 q46oth2f. Q46OTH3 q46oth3f.
         Q47BOX q47box. R9A1 r9a1ffff. R9B1 r9b1ffff.
         R9C1 r9c1ffff. R9D1 r9d1ffff. R9E1 r9e1ffff.
         R9F1 r9f1ffff. R9G1 r9g1ffff. R9H1 r9h1ffff.
         R9I1 r9i1ffff. R9A2 r9a2ffff. R9B2 r9b2ffff.
         R9C2 r9c2ffff. R9D2 r9d2ffff. R9E2 r9e2ffff.
         R9F2 r9f2ffff. R9G2 r9g2ffff. R9H2 r9h2ffff.
         R9I2 r9i2ffff. R9A3 r9a3ffff. R9B3 r9b3ffff.
         R9C3 r9c3ffff. R9D3 r9d3ffff. R9E3 r9e3ffff.
         R9F3 r9f3ffff. R9G3 r9g3ffff. R9H3 r9h3ffff.
         R9I3 r9i3ffff. Q47AW q47aw. Q47BW q47bw.
         Q47CW q47cw. Q47DW q47dw. Q47EW q47ew.
         Q47FW q47fw. Q47GW q47gw. Q47HW q47hw.
         Q47IW q47iw. BOXE boxe. Q48A q48a.
         Q48B q48b. Q48C q48c. Q48D q48d.
         Q48E q48e. Q49A q49a. Q49AU q49au.
         Q50A q50a. Q49B q49b. Q49BU q49bu.
         Q50B q50b. Q49C q49c. Q49CU q49cu.
         Q50C q50c. Q49D q49d. Q49DU q49du.
         Q50D q50d. Q49E q49e. Q49EU q49eu.
         Q50E q50e. Q49F q49f. Q49FU q49fu.
         Q50F q50f. Q49G q49g. Q49GU q49gu.
         Q50G q50g. Q49H q49h. Q49HU q49hu.
         Q50H q50h. Q51A q51a. Q51APC q51apc.
         Q51B q51b. Q51BPC q51bpc. Q51C q51c.
         Q51CPC q51cpc. Q51D q51d. Q51DPC q51dpc.
         Q51E q51e. Q51EPC q51epc. Q51F q51f.
         Q51FPC q51fpc. Q51G q51g. Q51GPC q51gpc.
         Q51H q51h. Q51HPC q51hpc. Q51I q51i.
         Q51IPC q51ipc. Q51J q51j. Q51JPC q51jpc.
         Q51K q51k. Q51KPC q51kpc. Q51L q51l.
         Q51LPC q51lpc. Q51M q51m. Q51MPC q51mpc.
         Q51N q51n. Q51NPC q51npc. Q51O q51o.
         Q51OPC q51opc. Q51P q51p. Q51PPC q51ppc.
         Q51Q q51q. Q51QPC q51qpc. Q51R q51r.
         Q51RPC q51rpc. Q52 q52fffff. Q53FMM q53fmm.
         Q53FDD q53fdd. Q53FYY q53fyy. Q53TMM q53tmm.
         Q53TDD q53tdd. Q53TYY q53tyy. Q54BOX q54box.
         Q54PC q54pc. Q55 q55fffff. Q56BOX q56box.
         Q56PC q56pc. TMEH tmeh. TMEM tmem.
         TMEAP tmeap. Q57FMM q57fmm. Q57FDD q57fdd.
         Q57FYY q57fyy. Q57TMM q57tmm. Q57TDD q57tdd.
         Q57TYY q57tyy. Q57A01 q57a01ff. Q57B01N q57b01n.
         Q57B01P q57b01p. Q57A02 q57a02ff. Q57B02N q57b02n.
         Q57B02P q57b02p. Q57A03 q57a03ff. Q57B03N q57b03n.
         Q57B03P q57b03p. Q57A04 q57a04ff. Q57B04N q57b04n.
         Q57B04P q57b04p. Q57A05 q57a05ff. Q57B05N q57b05n.
         Q57B05P q57b05p. Q57A06 q57a06ff. Q57B06N q57b06n.
         Q57B06P q57b06p. Q57A07 q57a07ff. Q57B07N q57b07n.
         Q57B07P q57b07p. Q57A08 q57a08ff. Q57B08N q57b08n.
         Q57B08P q57b08p. Q57A09 q57a09ff. Q57A09S q57a09s.
         Q57B09N q57b09n. Q57B09P q57b09p. Q57A10 q57a10ff.
         Q57B10N q57b10n. Q57B10P q57b10p. Q57BTN q57btn.
         Q58FMM q58fmm. Q58FDD q58fdd. Q58FYY q58fyy.
         Q58TMM q58tmm. Q58TDD q58tdd. Q58TYY q58tyy.
         Q58A01 q58a01ff. Q58B01N q58b01n. Q58B01P q58b01p.
         Q58A02 q58a02ff. Q58B02N q58b02n. Q58B02P q58b02p.
         Q58A03 q58a03ff. Q58B03N q58b03n. Q58B03P q58b03p.
         Q58A04 q58a04ff. Q58B04N q58b04n. Q58B04P q58b04p.
         Q58A05 q58a05ff. Q58B05N q58b05n. Q58B05P q58b05p.
         Q58A06 q58a06ff. Q58B06N q58b06n. Q58B06P q58b06p.
         Q58A07 q58a07ff. Q58B07N q58b07n. Q58B07P q58b07p.
         Q58A08 q58a08ff. Q58B08N q58b08n. Q58B08P q58b08p.
         Q58A09 q58a09ff. Q58A09S q58a09s. Q58B09N q58b09n.
         Q58B09P q58b09p. Q58A10 q58a10ff. Q58B10N q58b10n.
         Q58B10P q58b10p. Q58BTN q58btn. Q59FMM q59fmm.
         Q59FDD q59fdd. Q59FYY q59fyy. Q59TMM q59tmm.
         Q59TDD q59tdd. Q59TYY q59tyy. Q59A01 q59a01ff.
         Q59B01N q59b01n. Q59B01P q59b01p. Q59A02 q59a02ff.
         Q59B02N q59b02n. Q59B02P q59b02p. Q59A03 q59a03ff.
         Q59B03N q59b03n. Q59B03P q59b03p. Q59A04 q59a04ff.
         Q59B04N q59b04n. Q59B04P q59b04p. Q59A05 q59a05ff.
         Q59B05N q59b05n. Q59B05P q59b05p. Q59A06 q59a06ff.
         Q59B06N q59b06n. Q59B06P q59b06p. Q59A07 q59a07ff.
         Q59B07N q59b07n. Q59B07P q59b07p. Q59A08 q59a08ff.
         Q59B08N q59b08n. Q59B08P q59b08p. Q59A09 q59a09ff.
         Q59A09S q59a09s. Q59B09N q59b09n. Q59B09P q59b09p.
         Q59A10 q59a10ff. Q59B10N q59b10n. Q59B10P q59b10p.
         Q59BTN q59btn. Q60 q60fffff. Q61FMM q61fmm.
         Q61FDD q61fdd. Q61FYY q61fyy. Q61TMM q61tmm.
         Q61TDD q61tdd. Q61TYY q61tyy. Q61A01 q61a01ff.
         Q61B01N q61b01n. Q61B01P q61b01p. Q61A02 q61a02ff.
         Q61B02N q61b02n. Q61B02P q61b02p. Q61A03 q61a03ff.
         Q61B03N q61b03n. Q61B03P q61b03p. Q61A04 q61a04ff.
         Q61B04N q61b04n. Q61B04P q61b04p. Q61A05 q61a05ff.
         Q61B05N q61b05n. Q61B05P q61b05p. Q61A06 q61a06ff.
         Q61B06N q61b06n. Q61B06P q61b06p. Q61A07 q61a07ff.
         Q61B07N q61b07n. Q61B07P q61b07p. Q61A08 q61a08ff.
         Q61B08N q61b08n. Q61B08P q61b08p. Q61A09 q61a09ff.
         Q61A09S q61a09s. Q61B09N q61b09n. Q61B09P q61b09p.
         Q61A10 q61a10ff. Q61B10N q61b10n. Q61B10P q61b10p.
         Q61BTN q61btn. BIGNT bignt. SMALLNT smallnt.
         PSUTYPE2 psutypef. CENREG cenreg. CTCLIENT ctclient.
         FACTYPE factype. QFSTRAT qfstrat. STUDYIND studyind.
         OWN own.  ;
*/

RUN ;
